---
layout: post
title: A Free Culture License Wish List
date: 2020-03-29 07:59:26-0400
categories:
tags: [license, meta, opensource, freesoftware, gpl, creativecommons, copyleft]
summary: What I'd like to see in a hypothetical future Free Culture license
thumbnail: /blog/assets/hand-number-finger-community-together-handle-773437-pxhere.com.png
offset: -25%
proofed: true
---

As some people have argued over the so-called "ethical licenses" such as the [Hippocratic License](https://firstdonoharm.dev/) or MongoDB's [Server Side Public License](https://www.mongodb.com/licensing/server-side-public-license), I don't find that line of discussion *particularly* useful, but have started thinking more about what I'd like to see in a modern Free Culture license.

![Cooperation](/blog/assets/hand-number-finger-community-together-handle-773437-pxhere.com.png "Cooperation")

To make my disinterest in the ethical licenses clear and specific, I sympathize with the desire, but don't believe that a so-called "liberal" (in the sense of fewer terms, not social philosophy) software license makes a useful way to enforce "good" behavior and that the whole space opens the door for regressive moralizing attached to code.  And that doesn't even get into the strange compartmentalization that we often see outside of software, where philanthropic initiatives often enable and obscure the most unethical corporate behaviors.  I would much rather see ethics become a part of the software industry instead of constantly disclaiming responsibilities.  If a developer has the toolkit to refuse a task---not just because that work will hurt people, but because it'll damage the developer's career prospects---that becomes a real solution.

That all said, this may never come to anything and I have no interest in pushing anything here, I'd like to kick around some ideas for a hypothetical Free Culture license of the future.

## Contractual

As I [mentioned]({% post_url 2019-12-28-licenses %}) early on in the life of this blog, the easiest way to envision a public license working and the easiest way to make it function in a court of law involves treating it and writing it like a contract:  If the recipient provides the [consideration](https://en.wikipedia.org/wiki/Consideration) specified in the terms of the contract, then they receive a consideration in exchange, a trade of value.

Too many licenses---particularly the "liberal" licenses---don't include any mutual value exchanged.  The creator offers the code...and the "exchange" ends there.  And I don't *think* that makes them defensible in court, if it ever came to that.

## Universality

For thirty years, we've watched organizations create licenses and then turn around to tell us about all the kinds of works for which their licenses should *not* apply.

The Free Software Foundation's originally took the position that we should only worry about software running on our personal, general-purpose computers.  Art and text should hold no interest.  Firmware should hold no interest.  Hardware should hold no interest.  Servers should hold no interest...unless you ran those servers.  Even high-level software should hold no interest, as long as it ran on a dedicated device where the users couldn't easily run arbitrary software of their own.  Some of those deficits became problems---[TiVo](https://en.wikipedia.org/wiki/Tivoization)'s use of Linux triggering the [GNU GPL version 3](https://www.gnu.org/licenses/gpl-3.0.en.html) and the rise of interactive web sites triggering the [GNU Affero GPLv3](https://www.gnu.org/licenses/agpl-3.0.en.html)---while still ignoring other issues as someone else's problem.

Likewise, [Creative Commons](https://creativecommons.org/) still firmly recommends *against* using their licenses for software.  And unrelated [open hardware licenses](https://tapr.org/?page_id=5968) exist.  The same goes for [fonts](http://scripts.sil.org/cms/scripts/page.php?site_id=nrsi&id=OFL_web).  And [games](http://www.opengamingfoundation.org/ogl.html).  And [databases](https://opendatacommons.org/licenses/odbl/).  Other licenses for specific varieties of work exist, too, **many** others.

### What Defines "Source Code," Anyway?

One of the reasons I lean so hard on the phrase "Free Culture" comes from how, while we tend to refer a lot to "free and open works" (for example, see [FaOW](http://faow.referata.com/wiki/Welcome_to_Free_and_Open_Works!), a catalog of such content), the idea of "open art" seems...odd.

For an easy example, we can classify [Bicker](https://bicker.colagioia.net/) as software, so we can figure out what its source code consists of without much trouble.  The term "open source" makes some sense, here, for that reason.

However, now take [**Seeking Refuge**]({% post_url 2019-12-14-seeking-refuge %}), my novel.  I make the Markdown files available and have an entire section describing the inspirations and sources of the elements that I recognize contributed to the creation of the story.  Does that sufficiently "open" the story?  Have I shown my "source code" for the novel?  I have an entire cultural context and life-long education that would make it difficult for someone to reconstruct the final story from first principles.

And now let's take a step further and consider a photograph.  Hang on, do I have a photograph that I can use as an example, here?  Sure.  Here.

![Overgrown Brick](/blog/assets/overgrown-brick.png "Overgrown Brick")

OK, I have now released that picture---just like the rest of the blog---under a Creative Commons Attribution-Share Alike 4.0 International License, just like it says at the bottom of the page.  Personally, I would call it "Free Culture," to the extent that we can call the picture "culture," but it doesn't likely overlap anybody's definition of "open source," because...no real "source" *exists* to any significant extent, except if you count the full-resolution version from the camera.  I happened to walk past that spot and, since I carried my camera with me that day, took a picture when I saw that angle, because I liked it and feel confident that no copyright entanglements disrupt showing just the bricks and foliage.  But I can't really provide anybody with the bricks or the lighting.

The moral of that little story, then, could say that a universal Free Culture license needs to understand that distinction and require as much "source" as possible without requiring something that might not exist.

## Strong Copyleft and Reciprocation

To get the definition out of the way, [copyleft](https://en.wikipedia.org/wiki/Copyleft) exists in contrast with *copyright*, typically to imply that a creator has granted consumers limited rights over the work, provided that the consumers extend those same rights to others.  In other words, I share this blog with you and grant you the right to edit it and share it with others, if you want, but *only* if you give them the same rights as I've given you.

I tend to suspect that most people who choose non-commercial licenses and even the *ethical* licenses primarily seek to not risk the exploitation of the underlying work.  In that sense, I tend to agree with [Question Copyright](https://questioncopyright.org/cc-pro) in the analysis that copyleft prevents exploitation more efficiently than commercial restrictions:  Disney might easily roll the accounting dice to claim that their motion picture adaptation of your short story technically resembles a non-commercial use to fit the license, but they will *not* put a public license on their movie for other people (and companies) to use and adapt.

Similarly, I suspect that we can solve a lot of (though not all) Hippocratic-style issues by requiring that a derivative work publicly contributes its modifications back to the source project, assuming that they plan to abide by the terms of the license at all.  Even if they don't feel shame to admit to what they do with the code, contributing back gives the source project the ability to shame them in the public sphere.

For those reasons, I'd like to see the license not only require making changes available, but offering them back to the parent.

## Clear Attribution Terms

The MongoDB problem, as they've stated in various places, stems from a fear that an Amazon-like company will take their free product and sell access to it as part of a larger service like Amazon Web Services.

However, this seems like the opposite of the intent of releasing a database management system at no cost.  Hence, they re-licensed their product to a custom license that becomes largely contradictory, in that you can use the product for any purpose, but also *not* for some purposes.

However, this really stems from a problem of competition and monopolization.  However, if we replaced the SSPL with a strong copyleft license requiring reciprocation---as in the previous section---then they require Amazon (or whoever) to contribute back the changes they make to more easily make the database available, so the database company knows about this "threat" (assuming it constitutes a threat at all) and can compete on technical terms.  And to take this a step further, if you can't sign up for maybe-Amazon's hypothetical not-MongoDB service without seeing a clear link to MongoDB, who can then try to offer the same service for a competitive price, then maybe-Amazon no longer has the feared unassailable monopoly position.

![Book Ring](/blog/assets/bookringbasic_preview_featured.jpg "Book Ring")

We see a related but distinct problem when it comes to physical objects.  If I download a 3D model for [the above book ring](https://www.thingiverse.com/thing:144660) and print one on a 3D printer, the license requires attribution.  That works in theory, but...where does one put legible attribution with a URL to the designer's profile on an object so small, where the largest spaces should have smooth surfaces?  The object has no attribution attached, so we technically can't use the design in a way that complies with its license without making changes.  Licenses unfortunately ignore those issues, right now.

## Clear Patent/Trademark Guidance

Mozilla often comes [under](https://en.wikipedia.org/wiki/Mozilla_software_rebranded_by_Debian) [fire](https://wiki.hyperbola.info/doku.php?id=en:main:rusts_freedom_flaws) for not wanting their brands associated with compiled binaries for which they can't manage quality.  Technically, most Free Software licenses have this issue---the GPL has an explicit option to refuse to "grant rights under trademark law," for example---but people only seem to notice it when certain organizations and licenses involve themselves.

Patents create a similar issue, with some licenses specifically making patent grants and others...not so much.  For example, the GPLv3 says:

 > When you distribute a covered work, you grant a patent license to the recipient, and to anyone that receives any version of the work, permitting, for any and all versions of the covered work, all activities allowed or contemplated by this License, such as installing, running and distributing versions of the work, and using their output. This patent license is nonexclusive, royalty-free and worldwide, and covers all patent claims you control or have the right to sublicense, at the time you distribute the covered work or in the future, that would be infringed or violated by the covered work or any reasonably contemplated use of the covered work.
 >
 > If you distribute a covered work knowingly relying on a patent license, you must act to shield downstream users against the possible patent infringement claims from which your license protects you.

The Apache license works similarly.

 > Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted.

We might say, then, that a good license should at *least* make its terms clear around the rights under patent and trademark law, since software carries aspects of all forms of intellectual property.

As a parallel example, one of my concerns with using Creative Commons for **Seeking Refuge** precisely hits my trademark problem:  In theory, I would like a trademark on **The League of the Silver Bat**, as a franchise name, to protect against a hypothetical large media company from using the name and turning around to sue me when they find out that I exist.  However, doing that would require that I sue the people who I encourage to create derived works if they use the name prominently, to prove that I own and care about the trademark, which defeats the purpose of sharing.

Absent an "open trademark" license (I see a [draft of one](https://fabcommons.org/post/81178200555/open-trademark-license-otl) in Japanese, but I haven't seen any in actual use), I would minimally want my copyright license to include a trademark grant in the context of the derivative work, possibly requiring some variation on the trademark to distinguish the derivatives from the original; likewise, nobody accepting the terms of the license should have the ability to sue me over those trademarks.  No patents exist in this example, but the situation seems analogous.

## Compatibility

One of the things I like least about Creative Commons revolves around their continued treatment of non-commercial licenses as first-class citizens of their system, since it creates two bodies of mutually unintelligible works.  I don't mean this in the sense of "I want to use [**Pioneer One**](http://www.pioneerone.tv/) as part of a space opera franchise"...even though that would make an excellent idea for someone willing to work with the non-commercial license, but rather---as a brief example---they can't adapt content from [*Stardrifter*](https://archive.org/details/Stardrifter/) and *Stardrifter* can't adapt anything from **Pioneer One**, since each license requires perpetuating terms that contradict the other license.

A similar problem arises in the relationship between Creative Commons licenses and the GPL.  Currently, the various groups have an informal agreement in place carving out exceptions for GPL-licensed software to use content licensed CC-BY-SA, but the inverse doesn't work.  Therefore, apart from [Fair Use](https://en.wikipedia.org/wiki/Fair_use) considerations, most people don't find it feasible to include source code from a GPL-licensed project in a Creative Commons-licensed story or---in some cases, because the license refuses to acknowledge output---even use GPL-licensed software in a Creative Commons-licensed video.  I don't include screenshots of software in this blog (except for my own) for this reason.

If you'd like a more concrete example of GPL/Creative Commons conflicts, consider that the authors of most of the books on [FLOSS Manuals](https://www.flossmanuals.net/) have licensed them under the GPL, in the interest of having the ability to integrate the documentation with the software, at some point.  But because of this, a person can't integrate the books with other content under strong-copyleft licensing---I'll continue to use this blog as an example, though Wikipedia and related projects come to mind as stronger contenders---without revising the license to the GPL.

Therefore, a modern license needs to have some awareness of the needs of other licenses, so that incompatible terms can coexist on at least some limited basis.  For example, if I had some wild plan to create a film where the characters use a lot of Free Software, it might work well enough if the license forbade modifications to the displayed software and required that the film mark them as licensed separately.  Likewise, I wouldn't mind if my license for **Seeking Refuge** included terms that allowed for people to use extended excerpts, regardless of their license, with tighter integration than that requiring tighter conformance to licensing terms.  We could improve that situation, if its terms had enough flexibility to integrate GPL and CC-BY-SA content and reciprocate instead of only creating a one-way or no-way transfer.

## Contributor Rights

[Contributor License Agreements](https://en.wikipedia.org/wiki/Contributor_License_Agreement) create terms required for contributing to a project that cede all rights to the owners.  Generally, companies use these agreements when they might want to eventually change the license of software under the GPL, eventually taking later versions proprietary once the market for the product proves itself.  Sure, we could make other theoretical arguments about why a company might impose a CLA on people giving them gifts, but in practice, finding an exception to the general rule won't happen often.

We can see a related but lesser issue that, as the holder of the original copyright, up until people contribute to my projects, I don't need to abide by the terms of their licenses.  I can (don't worry, I *won't*, but I could) write a series of blog posts---licensed as CC-BY-SA---that just reprint [SlackBackup](https://github.com/jcolag/SlackBackup) code or print snippets on hats, whereas you can't, because you have received the software under the terms of the GPL.

I don't know if anyone can ever solve the latter problem, assuming that we didn't just abolish copyright entirely.  However, a policy of "copyleft in, copyleft out," suggesting that code contributed under the terms of the license can't see a re-release under other terms *might* handle both issues.  Bear in mind that the latter problem will always have a weaker solution, just copyright inherently just creates a limited-term monopoly on what you create.  But, such a change still takes a baby step, and would scuttle any attempt to impose a CLA outright.

## Digital Rights Management

Unfortunately, this create a much more dicey issue than the others.  [Digital Rights Management](https://en.wikipedia.org/wiki/Digital_rights_management) provides "locks" on content, designed to ensure that access to the content remains exclusive.  DVDs, for example, undergo---trivial, these days---encryption to make it more difficult to watch a movie on your PC where you might copy it.  Most streaming services use [Encrypted Media Extensions](https://en.wikipedia.org/wiki/Encrypted_Media_Extensions), a specific form of DRM, to similarly make it difficult to consume the book/music/movie/whatever on any device at any time.

Because it takes research and development to implement these locks, prices go up.  And, as you probably know, they don't really work, and one would find it *really* easy to get just about any current property on some pirate distribution network, if that sort of thing excites you.  (Personally, I don't condone piracy, because it still gives these abusive companies more mind-share, even if they don't receive money.)

As many others have said many times before in this context---I believe originally by Cory Doctorow, but can't find the quote---that nobody wants to pay more for a product whose distinguishing feature is that someone made it harder to use.

Because of that, I don't at all know what form I would like this to take, but at least the *option* of forbidding distribution of a work through restricted channels seems well in the spirit of this.  Nobody really has a problem with selling a work.  Expecting that sold work to lock itself to a specific device or user, however, represents a corporate fantasy, and---if nothing else---creators should have a say in what happens to the works created using their work.

## Simplicity

One of the biggest objections that I've heard regarding the GPLv3 comes from how it clocks in at 5,644 words, long enough that few developers have read it---almost twice the length of this interminable post---and, therefore, most developers don't actually know what terms that they offer or agree to, except in the broadest sense.  By contrast, the MIT License hits around 170 words and, while the license has its weaknesses, we have a better chance that you've read that than the GPL.

While a lot of the difference obviously involves added features, a modern license should also structure itself in a way that encourages reading and comprehension, ideally also including a summary like the Creative Commons "deeds."

## Clear Licensing

It occurs to me that I don't think that I have ever seen a public licensing statement attached to a public license.  In fact, the [GPL](https://www.gnu.org/licenses/gpl-3.0.en.html)'s authoritative copy has the following line just before the Preamble.

 > Everyone is permitted to copy and distribute verbatim copies of this license document, but changing it is not allowed.

In other words, nobody but the Free Software Foundation can legally create derivative works based on the GPL.

By contrast, the Creative Commons licenses, such as [CC-BY-SA](https://creativecommons.org/licenses/by-sa/4.0/legalcode), have a section at the end including:

 > The text of the Creative Commons public licenses is dedicated to the public domain under the CC0 Public Domain Dedication.

I can't really say that either makes more sense or that this issue represents the most critical problem in the world, but I actually feel the tiniest bit of discomfort using the GPL, now, because I distribute a copy of usually the AGPL with my software, in repositories that carry licenses saying that you have permission to change anything that you like.  The way I read the disclaimer, it would also forbid the possibility of making an audio recording of the license, since that doesn't copy of the *document*, but rather creates an interpretation.

Of course, you shouldn't name your derivative license after the original (see the foregoing about trademarks), but the idea that licenses don't have licenses seems...odd.  It won't change how I work, but it serves as something that I would like to see resolved.

## Rant Over

Keeping in mind that nobody appears to have a project to create a next-generation copyleft license and that I have all the authority of some random guy who happens to use copyleft licenses, that should cover a decent outline of what I would like to see if those conditions didn't apply:  Written like a contract, not written for a specific kind of product, strong reciprocation requirements as compensation for work, clear attribution guidelines, patent- and trademark-aware, not adversarial towards similar licenses, adversarial towards CLAs and DRM, easy to understand, and available (ideally) under its own terms.  I think that would resolve a lot of current problems and set the community up for better collaboration in the future.

Would we see adoption of a license like this among big corporations?  Probably not, and such a license could cause problems for some developers.  But as I've mentioned previously, driving out the companies who use Free Culture as a source to harvest without compensation feels like a benefit to me, not a drawback.

Does this solve the problems that the "ethical" licenses seek to solve?  Not directly, no, but I also don't think many people and organizations exist, who would have no problem violating human rights or committing war crimes, but would balk at violating the terms of a license that may not actually hold up in court.  We might see an analogy in imagining that we can stop murders by reducing the speed limits in dangerous neighborhoods, to make it harder for the murderer to escape, because nobody *ever* speeds.

Don't get me wrong.  I appreciate the sentiment behind these licenses.  But I think the better approach starts with making it unacceptable to violate human rights, rather than to release something under a "liberal" license and idly wag a finger at organizations that enables arbitrary arrest.  And we certainly have ways to do that, but when the pitch for a new license includes a lengthy discussion about how nobody cares about licenses, the new license doesn't have much punch as a protest.

And if you've read all the way down this far, I think that I can presume that this overlaps fields that interests you, so...what features do *you* want in a license?

#### <i class="fas fa-file-contract"></i>

* * *

**Credits**:  Untitled header photograph [from PxHere](https://pxhere.com/en/photo/773437), made available under the [CC0 1.0 Universal Public Domain Dedication](https://creativecommons.org/publicdomain/zero/1.0/).  The [book ring](https://www.thingiverse.com/thing:144660) by [Frank Erfurth](https://www.thingiverse.com/alohapussycat/about) is available under the terms of the [Creative Commons Attribution-Share Alike 3.0 license](https://creativecommons.org/licenses/by-sa/3.0/).
