---
layout: post
title: Copyright Searches
date: 2020-07-19 08:31:23-0400
categories:
tags: [copyright, publicdomain]
summary: How to search for copyrights
thumbnail: /blog/assets/Statute_of_anne.jpg
offset: -33%
recommend: An amateur guide to checking copyright status
---

As is [probably obvious]({% post_url 2020-01-01-hny %}), I have a soft spot in my heart for material that's in the public domain, for people to use and adapt for their own purposes.  It's the relative absence of a modern public domain that spurred the Free Culture movement, which adds protections against someone making small-but-useful changes to an original work in order to secure a new copyright.

So, because I like having information in one place, this is a rough guide for checking copyright status on a work in the United States.

![The Statute of Anne](/blog/assets/Statute_of_anne.jpg "The Statute of Anne, arguably the world's first copyright law")

As the obvious boilerplate **disclaimer**:  I'm not a lawyer.  If I was a lawyer, I wouldn't be *your* lawyer.  Taking legal advice from me is worth what you paid for it.  If you're planning on running a business based on republishing or adapting public domain resources, you should hire a reputable lawyer who specializes in copyright law and has someone who lives near the Library of Congress to execute and document research on your behalf.

## History

Before we get into the summary, let's walk through the various copyright laws, so that we don't miss anything.  If you want to skip it, you can head right down to the [copyright search](#checking-for-copyrights) part.

### Original U.S. Copyright Law

In the [Copyright Act of 1790](https://en.wikipedia.org/wiki/Copyright_Act_of_1790), maps, charts, and books were protected by copyright for fourteen years, with an optional fourteen-year renewal period.  The [Statute of Anne](https://en.wikipedia.org/wiki/Statute_of_Anne) used as the header above didn't extend to colonies and the [Articles of Confederation](https://en.wikipedia.org/wiki/Articles_of_Confederation) didn't give the Continental Congress any right to issue or protect copyrights.

Things you probably want to know about the law:

 * Only U.S. citizens were permitted to apply for copyright protection.
 * Publishers had a maximum of six months to file for their copyright protection.
 * Renewal needed to be filed six months prior to the first term's expiration.
 * Music compositions were routinely unofficially protected as if it were a book.
 * Copyright infringement had a statute of limitations of one year.
 * Adaptations are *not* covered by the law.

You can [read the full text](https://en.wikisource.org/wiki/Copyright_Act_of_1790), and though it has been repealed and replaced by multiple more recent laws that we'll talk about, it's less than a thousand, three hundred words, so is an easy read.

### The 1831 Law

Next, we had the [Copyright Act of 1831](https://en.wikipedia.org/wiki/Copyright_Act_of_1831), which doubled the initial copyright term to twenty-eight years, the statute of limitations to two years, plus added music as a protected category, and allowed the copyright holder's heir to file for renewal, if the author was dead.

While this law held, 1856 allowed a copyright holder to block public performances of their works, 1861 made copyright cases eligible for Supreme Court appeal, and 1865 added photographs to the list of works that could be protected under copyright.

Otherwise, the law is similar, if more verbose.

### On to 1870

The [Copyright Act of 1870](https://en.wikipedia.org/wiki/Copyright_Act_of_1870) actually covered Intellectual Property in general, but the copyright side largely just accounts for adaptations and other derived works as activities controlled by the copyright-holder.

Most of the later amendments are irrelevant, but 1882 saw an adjustment to allow for non-obvious copyright statements on works that are meant to be used.

### 1891 and International Copyrights

The [International Copyright Act of 1891](https://en.wikipedia.org/wiki/International_Copyright_Act_of_1891) allowed for extending copyright protection to non-citizens, provided the filed for it prior to publication if the country provides the same for American authors and if the author applies for copyright before publication and needed to have manufacturing and distribution in the United States.

### A Few Years Later

The biggest effect of the [Printing Act of 1895](https://en.wikipedia.org/wiki/Printing_Act_of_1895) is the ban on copyrights for works of the United States government.

Penalties were created for asserting false copyright in 1897.  Temporary, two-year copyrights for foreign works not otherwise complying with the 1891 law were added in 1904 and 1905.

### Early Twentieth Century

The most influential copyright law was the [Copyright Act of 1909](https://en.wikipedia.org/wiki/Copyright_Act_of_1909).  It doubled the copyright renewal term length to match the twenty-eight years of the first term, providing a maximum of fifty-six years of protection.

The law also simplifies copyright protection to those with a well-formed copyright statement, and adds a compulsory mechanical license for recording music.

Motion pictures were added to the list of fixed works in 1912.  In 1941, requirements were relaxed during times of emergency, so that creators sent to fight in World War II didn't miss an opportunity to file applications.

### Late Twentieth Century

The modern law that tipped the scales from copyright for the public interest to copyright as a benefit to authors is the [Copyright Act of 1976](https://en.wikipedia.org/wiki/Copyright_Act_of_1976), meant in part to allow the United States to join in international copyright treaties.  The law expanded the types of works covered by copyright, as usual.  It also extended the existing renewal term for works still under copyright from twenty-eight years to forty-seven, for a total of seventy-five, while also changing new copyrights to a term that includes the time from publication to fifty years after the author's death.  A change we'll find relevant is that copyright notices are now more flexible, and can be omitted on a small fraction of copies, as long as either an effort was made to fix the problem within five years (like altering the print run) or the error was in violation of the author's contract with the publisher.

There are other aspects, such as seventy-five year fixed terms for works for hire, copyright transfer, termination of transfer, and Fair Use rules, but those don't really affect us, here, or are so close to another aspect that they blend in.

### Berne

The aforementioned copyright treaties began changing copyright law with the [Berne Convention Implementation Act of 1988](https://en.wikipedia.org/wiki/Berne_Convention_Implementation_Act_of_1988), which removed copyright formalities, such as requiring a copyright statement in publications.

### On to 1992

The [Copyright Renewal Act of 1992](https://en.wikipedia.org/wiki/Copyright_Renewal_Act_of_1992) automatically renews works still covered under their first copyright term.

### Uruguay

The [Uruguay Round Agreements Act](https://en.wikipedia.org/wiki/Uruguay_Round_Agreements_Act) granted a "restored" copyright on foreign works from countries that are a party to the Berne Convention and either didn't comply with United States copyright law at the time of publication or didn't file for renewal.  The restored copyrights stand as if the works had been published in the United States, and the law has withstood multiple cases against its constitutionality.

### Mickey Mouse Enters the Fray

Sonny Bono's [Copyright Term Extension Act](https://en.wikipedia.org/wiki/Copyright_Term_Extension_Act) increased existing copyright terms by twenty years, extending the renewals to sixty-seven years and new copyrights to seventy years after the death of the author, with corporate terms lasting for ninety-five years *or* one hundred twenty years after creation, for companies that sat on a work for years before publication.

### Millennials Ruin Everything

The [Digital Millennium Copyright Act](https://en.wikipedia.org/wiki/Digital_Millennium_Copyright_Act) doesn't change terms, but it turns code into its own sort of copyright, by banning the bypass of "digital locks."

I apologize for using the term "millennial."  I'm well aware that named generations are [garbage pseudo-science](https://en.wikipedia.org/wiki/Strauss%E2%80%93Howe_generational_theory), and that the millennial name was conflated with [millennialist](https://en.wikipedia.org/wiki/Millennialism) ideas about the Second Coming of Christ, to produce the idea that young men and women were going to start [World War III](https://en.wikipedia.org/wiki/War_on_terror) in the Middle East, and the protests and general lack of military enlistment is why "millennials are lazy" and "ruining everything."  Yes, I get all that and apologize for perpetuating it, but also wasn't about to let it get in the way of a pun.

### We Keep Forgetting Music

Finally, as of 2020, the [Music Modernization Act](https://en.wikipedia.org/wiki/Music_Modernization_Act) gives old music recordings a legitimate nation-wide copyright (instead of a patchwork of state and local laws, plus district court decisions) that expire starting in 2022, with all recordings published prior to 1923.  Every year after that, the copyrights for recordings for the following publication year expire, ninety-nine years later.

## Checking for Copyrights

OK, that's all fine, but what does this all **mean**...?

One massive problem with trying to determine if something is in the public domain is that you can never be sure.  It's always possible that there was a transcription error, a misfiled document, a special case, or any number of other cracks that information could have slipped through.  Because of this, you can prove that something has a copyright, but you can only ever be *reasonably sure* to a chosen tolerance that a work has no copyright.  If a creator's estate shows their copy of documentation you couldn't find, then you're in the wrong.

In other words, tread carefully.  If you're not comfortable without a complete answer, this probably isn't something you want to try.

That said, there are some decisions that are easier than others.

### The Oldest of the Old

First off, with some exceptions, we can probably assume that any work published prior to 1909 has no copyright protection in the United States.  We know this, because any works published inside the United States have no copyright protection and any works published outside the United States had no grounds for protection under United States law.

However, there are exceptions, most notably stemming from the [Uruguay Round Agreements Act](#uruguay) as described previously.  Conveniently, the Copyright Office maintains a list of the [restored copyrights](https://www.copyright.gov/gatt.html), with enough information that you should be able to rule out the possibility, if you have such a work in mind.  This link applies to all subsequent categories, up to the present day.

### No Statement, No Copyright

Another easy check is that, up until [1978](#late-twentieth-century), a copy of a work without a well-formed copyright statement in a prominent position (except for utilitarian works, where it might be less prominent) is not eligible for copyright protection.  A [well-formed notice <i class="far fa-file-pdf"></i>](https://copyright.gov/circs/circ03.pdf) comes in one of the two following forms.

 > © YEAR Owner, such as this post being "© 2020 John Colagioia"

Alternatively, if you're in a medium where special characters aren't convenient, there's a more explicit alternative.

 > Copyright YEAR Owner (the word "copyright" doesn't need to be capitalized.)

In addition, prior to March 1989, works published without a copyright notice where there was no attempt to fix the missing notice were also not eligible for copyright protection, provided the author doesn't have a contract requiring it.  However, that's obviously more difficult to determine.

### Works of the United States Government

Also easy is that, if something was produced by the United States federal government or an agency of the government, it can't claim copyright protection.  However, this does *not* apply to works created by contractors, so check and double-check anything you might plan to use.

### The Famous Copyright Date

The next easiest is that we all remember what's now the ninety-five rule, where anything published in the United States in 1924 or earlier has also lost its copyright, unless that copyright has been restored.

For many years, due to the extension of terms, this date was fixed at 1922, but the calendar has finally caught up to copyright law.

### Up to 1963

Because of [automatic renewals](#on-to-1992), anything that was still under copyright in (1992 - 28) 1964 hasn't needed a renewal, and will only have its copyright protection expire when the previous section catches up to it.

However, for works published ninety-five years ago or less, and prior to 1964, they *did* require renewal, and we can check for those renewals.  However, renewals might live in two places.

For books published through 1950, you want to search through **The Catalog of Copyright Entries**, of which there are scans linked from [The Online Books Page](http://onlinebooks.library.upenn.edu/cce/).  You'll need to check the renewal 28 years after the book was published.  If it's not there, also check the second half of the previous year and the first half of the next year, because the Copyright Office has been known to be flexible.  If there is no renewal, the book is *probably* in the public domain.

I say "probably," because---like I said [above](#checking-for-copyrights)---there might have been a spelling error, a transcription error, a filing error, or a name that you're not aware of.  For periodicals, you should *also* check the "Books and Contributions to Periodicals" section, if you can find a copyright statement listed anywhere in the book's interior, to make sure that it's not separate material bundled together, and that search may be more difficult.

In addition, every issue of a periodical has its own potential copyright, not the title as a whole, so every issue of interest needs independent verification.

For books published from 1950 to 1963, the US Copyright Office has a [searchable database](http://cocatalog.loc.gov/), which is a lot less frustrating to work with than reading through PDFs hoping that some overworked clerk didn't alphabetize their list incorrectly.  Search for what you want (with the same disclaimer above, regarding typos), and if whatever you're searching for comes back with a number (to the right) starting with an R, that's a renewal.

Did you notice that I mentioned 1950 for both searches?  The year that copyright records went digital...not *all* of the copyright records went digital.  So, if the work you're interested in was published in 1950, you have the great pleasure of searching in both places.

#### An Example

This sounds like it might be difficult, but is relatively straightforward, so let's pick a typical example, **Exciting Comics** #9, the first appearance of the [Black Terror](https://en.wikipedia.org/wiki/Black_Terror), a popular character.  I've chosen it because it comes up in conversation a lot.

First, we need to know what we're looking for, so we look at the periodical's indicia, where the copyright information "lives."

![Exciting Comics #9](/blog/assets/exciting9indicia.png "Exciting Comics #9's indicia")

I've highlighted (in green) two things we want to see.  First, is the copyright notice.  It looks a bit off, but it's well-formed, with the word "copyright," the year, and the owner.  We also have the official numbering of the periodical, "Vol. 3, No. 3."

Twenty-eight years after 1941 is 1969, so we rush to **The Catalog of Copyright Entries** (**CCE**), looking for [renewals to periodicals in 1969](https://archive.org/stream/catalogofcopy19693232libr#page/385/mode/1up), linked from [the 1969 page](https://onlinebooks.library.upenn.edu/cce/1969r.html).  We jump to the end of the E's to find **Exciting Comics**, but too late, because these renewals start with Vol. 5.

![The renewals for 1969](/blog/assets/exciting1969renewals.png "The renewals for 1969")

No worries, because we remember that we also need to look before and after that year, and we obviously need the "before," the [renewals](https://archive.org/stream/catalogofcopy19683222libr#page/383/mode/1up) from [1968](https://onlinebooks.library.upenn.edu/cce/1968r.html).  This is the same deal as before, running down to look for **Exciting Comics**, and...here we are.

![The renewals for 1970](/blog/assets/exciting1970renewals.png "The renewals for 1970")

I've highlighted the renewal for clarity, but we can see the original copyright (B489015) and the renewal (R449263) for v3n3.  So, somebody still owns the rights to this book.

We *might* be able to do some research to determine whether Popular Library had the right to renew a periodical from Better Publications, Inc., if we had the resources to untangle those companies, but I don't know of a known case where a copyright renewal was successfully filed fraudulently, since the law is specific about who can file.  We might also be interested in knowing that [Popular Library](https://en.wikipedia.org/wiki/Popular_Library) is currently owned by [Hachette Book Group](https://en.wikipedia.org/wiki/Hachette_Book_Group), after spending some time owned by Fawcett Publications, CBS, and Warner Brothers, because any of those companies might currently own B489015/R449263.  Or, it might have been sold to an employee who wanted it.

This is where a copyright search requires significant resources:  If you want to use the Black Terror, you'll presumably need to license the story that provides the earliest information on the character, and that requires looking for copyright transfers and following lines of inheritance and corporate sales.

Regardless, as mentioned a couple of paragraphs back, *somebody* owns the rights to this book unless we can legitimately argue that the copyright renewal was a fraud, so if we're looking for something in the public domain, we'll need to look elsewhere.

If we didn't find the renewal, I'd recommend searching for misspellings, seeing if the book ever went by another title that might have been used, and potentially even check the other sections of the **CCE**, in case the renewal was filed incorrectly.  Or, if we're not expecting to make much money from the venture, we might accept the risk of Hachette or another company sending a Cease and Desist order.

If we're interested in something else, such as a book, a short story, a song, a play, a photograph, or anything else covered by copyright, we would go through the same process, but we'd check a different section of the **CCE** and some sections are sorted by the name of the author instead of the name of the work.

### 1989 and on

Modern works have copyright automatically fixed and that copyright term lasts for the life of the author (or the longest-lived author, in a collaboration), plus seventy years.  Therefore, the only way that the work will *not* be under copyright is if the author actively surrenders the work into the public domain.

But that is non-trivial, as reporters at [Dave Fagundes and Aaron Perzanowski](https://www.vice.com/en_us/article/qjdnmp/its-too-hard-to-put-artwork-into-the-public-domain) found out and released into the public domain, back in March.  As they point out:

 > The Copyright Act doesn’t mention abandonment. The Copyright Office takes no position on whether these efforts to abandon are effective. And no court has yet determined that they get the job done. So while many owners believe they’ve abandoned their works, whether they’ve actually managed to do so remains an open question.

In other words---they provide examples in the article and in their paper---the courts don't consistently believe that a statement placing a work into the public domain or is not subject to copyright protection is actually sufficient to do so.  So, be wary of using content even with a CC0 license; if the creator or an heir decides they want money, a court might decide you owe them.

### Non-Treaty Countries

Something that sounds simpler than it is, finally:  For works created in a country that isn't a party to any copyright treaty the United States participates in, they are not eligible for copyright protection in the United States and so can be considered a part of the public domain.

However, there aren't many such countries and, if they do join one of the treaties, those works will gain a restored copyright.

### Unpublished Works

In just about all cases other than corporate ownership, unpublished works have implied copyrights lasting for seventy years after the death of the author...unless it was subsequently published, at which point that term applies, instead.

Obviously, this is an edge case, since most people don't have access to someone else's unpublished works unless we physically buy a physical manuscript.  I say "bought" because, if you inherited the unpublished manuscript, then you (check with the estate lawyer) probably inherited the copyright on it, as well, and so wouldn't need to care about the copyright term.

## Red Flags

There are a few ideas that don't make sense in a copyright discussion, but still come up in copyright discussions.  I would argue that, if you hear the terms used in this context, the people speaking either don't know what they're talking about, or they're speaking *so* abstractly that their comments are meaningless.  Either way, continue with care.

### Orphan Works

There is no such thing, legally, as a work without an owner, unless it has fallen into the public domain by one of the above processes.  You might not know who owns it.  The owner may not know they own it.  Somebody, however, owns it.

So, you can really think of the term "orphan work" as code for not caring that the work is still protected by copyright, because it doesn't seem like the owner is going to sue anybody.

### Characters

Legally speaking, there is no such thing as a fictional character, and so they do not have any kind of independent copyright status.  Characters are elements of stories, so "using a character" means creating a derived work based on the source of that character, and that work (or set of works) has a copyright (or set of copyrights) that you can research.

This gets into tricky territory, as you'll see if you look at the case law surrounding character-based copyright infringement lawsuits.  In [National Comics Publications, Inc. v. Fawcett Publications, Inc.](https://en.wikipedia.org/wiki/National_Comics_Publications,_Inc._v._Fawcett_Publications,_Inc.), Fawcett was found to have sufficiently diverse sources as to not be copying Superman stories, but on appeal, the judge pointed out that there were many situations and images that were absolutely copied without infringement.  In [Warner Bros. Inc. v. American Broadcasting Companies, Inc.](https://en.wikipedia.org/wiki/Warner_Bros._Inc._v._American_Broadcasting_Companies,_Inc.), a then-new television show was found (in essence) to be using the Superman archetype in a transformative way to create something new, and so wasn't infringing.  In [Warner Bros. v. Columbia Broadcast Systems](https://openjurist.org/216/f2d/945/warner-bros-pictures-v-columbia-broadcasting-system-b), the court found that Dashiell Hammett's "Sam Spade" character didn't have sufficient distinguishing characteristics in his original story to be considered a sufficiently strong element capable of infringement.  There are also many cases where the court ruled that the use of the character was neither transformative nor justified, and was just illegally deriving from a protected work.

This is also tied up in trademark and many other issues.  Wikipedia has [an excellent article](https://en.wikipedia.org/wiki/Copyright_protection_for_fictional_characters) with some of the more interesting case law.

## Open Questions

In case you weren't sufficiently concerned about the ambiguity of some copyright searches, here are some additional wrinkles that you might find.

 * In some cases, instead of a renewal number, **The Catalog of Copyright Entries** might say something to the effect of "consult Copyright Office."  I haven't discovered who at the Copyright Office should be consulted or what special information they have.  My *guess* is that the full paperwork was either in-progress or misplaced when the time came to type up the final copy, but I have not confirmed that and the folks at the Copyright Office e-mail didn't have any theories when I checked there, suggesting I visit and ask the desk.

 * Likewise, nobody I have been able to find seems to know if the "fix the missing copyright notice within five years" rule applies to periodicals and what that would look like.  Again, my *guess* is that it's impossible, since the print run is short and not repeated, but it's possible that some large publisher found a work-around.

 * You'll notice that, other than restored copyrights and prior to 1909, I've avoided foreign copyrights.  That's because---last I checked, and I apologize that I can't find the case references to be more specific---the situation is inconsistent.  United States law doesn't specify whether to use the so-called "Rule of the Shorter Term" (where a work is granted the least copyright protection of its home country or its host country), so different district courts have ruled differently.

 * Stranger, the ninth circuit (Alaska, Arizona, California, Guam, Hawaii, Idaho, Montana, Nevada, Northern Mariana Islands, Oregon, and Washington) follows [Twin Books Corporation v. Walt Disney Company](https://caselaw.findlaw.com/us-9th-circuit/1304377.html), stating that books published overseas in a language other than English are to be treated as unpublished works (up until 1978), unless and until it is republished with a United States copyright statement.  The Copyright Office does not mention this decision, so it's unknown how other district courts would rule.

 * As an additional twist to foreign copyrights, national copyright laws have changed over time, just like they have in the United States.  Sometimes, the changes are retroactive, such as in the United Kingdom.  Sometimes, they are not.  To my knowledge, nobody has compiled a reference of which countries have a public domain that has works from multiple laws and what rules are available to apply, there.

I'm sure there are others.  Those come immediately to mind, however, and are questions where I'd be grateful, if the answers were to show up.

## Whew!

This is a lot, but here's what you should take away from this:

 * If you need your analysis to be right, you need to pay a lawyer, who has access and experience that most people can't easily get.

 * However, for most purposes, none of this information is secret or difficult to comprehend, so you should do your own research, instead of relying on anybody else's statement on copyright status, except for a statement from your lawyer.

 * There are edge cases to worry about, especially regarding foreign copyrights.

So, the work can be tedious, but it's not difficult.  It's simple enough that it may be possible to partly automate the process, but the data isn't regular enough to make that easy, unfortunately.

* * *

**Credits**:  The header image is the start to the Statute of Anne, what's typically identified as the world's first copyright law, old enough to itself be in the public domain.  The **Exciting Comics #9** incidia is used in the spirit of Fair Use.  The excerpts of **The Catalog of Copyright Entries** are in the public domain, as works of a United States government agency.
