---
layout: post
title: Announcing All Around the News
date: 2021-04-25 17:06:12-0400
categories:
tags: [announcement]
summary: The start of a new kind of news site
thumbnail: /blog/assets/AllAroundTheNews.svg
offset: -13%
---

If you follow the [**Entropy Arbitrage** newsletter](https://entropy-arbitrage.mailchimpsites.com/), you know that this has been "coming soon" for an absurdly long time.

[![All Around the News logo](/blog/assets/AllAroundTheNews.svg "All Around the News logo")](https://allaroundthe.news)

For a while, I've found myself wondering about the economics of journalism.  I can estimate how much it costs to produce an article, but I have no idea what it takes to get and retain readers.  I don't know what the advertising landscape looks like.  And I don't really know what alternative funding models are out there.

The easiest way to solve that information gap, of course, is through experience.  Hence, [**All Around the News**](https://allaroundthe.news) goes live.

It's later than I wanted, because everyone involved has apparently chosen to make it *more* complicated to run a Ruby on Rails app behind a web server---and secure it with [HTTPS](https://en.wikipedia.org/wiki/HTTPS)---rather than easier.  I understand that everything needs to be more flexible, but the number of elements with different package names *and* non-working packages would be comedic, if I didn't know that millions of people rely on it.  Unlike most hassles, I will *not* turn this into a [tech tip](/blog/tag/techtips) post, because I expect that most of it will change too quickly to be useful to anybody but me.

Anyway, the first version works, so I can finally stop talking about how it'll be released "soon."

## Phase One

This initial version is---to be completely honest---nothing special.  The site republishes articles that are available under a Free Culture (or near enough) license, deliberately ignoring images and videos---most header images are stock photos, anyway---to maximize the speed of the website and keep the layout clean.  The site doesn't make any money, yet, so there isn't exactly a budget for hiring journalists or buying articles, meaning that all content can be found somewhere else.

Each article has links to share on social media, donate (I'll get back to this in a bit), and visit the original.

The donation link, currently, is a key experiment.  For any news source that solicits donations, **All Around the News** nudges the user to donate there, to support their work.  For all other news sources, it directs the user to a [Buy Me a Coffee ☕](https://www.buymeacoffee.com/jcolag) page that I quickly threw together.  Internally---and this is the *big* experimental part---I count the number of times that people click the article's donation link, and how many people continue on to where they might actually donate money.  (And hey, if *you* want to throw some money at me, I promise to put it to good use.)

I also opened one space for an advertisement, via [Intravert](https://intravert.co/), which appears to be a fairly ethical option, as such things go.  I expect that I'll eventually need to compromise, there, given that I'm starting with no audience, which will lead us to the near future.

Overall, though, the core premise for this version of things is that we have a news site that looks nice enough to read from, rather than cluttering the page with images, interruptions, and other utterly dismal design features.

### News Sources

If you'd like a taste of what **All Around the News** looks like to start without visiting---I'm sure I have some odd readers---here's a list of sites whose articles we use.

 * ~~[Common Dreams](https://www.commondreams.org/) has good content, but is also problematic in how many stories are about a progressive figure or organization releasing a statement.~~ **Update**:  At some point since I initially posted this, Common Dreams abruptly shifted to a non-commercial license, excluding them from use.
 * [The Conversation](https://theconversation.com/us) has some fascinating stories on a wide array of topics.
 * [Futurity](https://www.futurity.org/) mostly releases announcements of science done at universities.
 * [National Aeronautics and Space Administration](https://www.nasa.gov/), I assume that you've heard of.
 * [National Transportation Safety Board](https://www.ntsb.gov/news/Pages/default.aspx) isn't a traditional news organization, but their reports on crashes are a surprisingly interesting read.
 * [OtherWords](https://otherwords.org/) releases a weekly handful of opinion pieces by a diverse group of writers.
 * [Share America](https://share.america.gov/) is a project of the Bureau of Global Public Affairs, alternating between current events and historical summaries.
 * [United States Department of Defense](https://www.defense.gov/Newsroom/) is a biased source, of course, but it's always worth knowing what the military is working on.
 * [United States Geological Survey](https://www.usgs.gov/news/) doesn't publish frequently, but they regularly discuss wildlife and satellites, in addition to earthquakes.
 * [Voice of America](https://www.voanews.com/) is probably the closest thing to a conventional news source, tending to be unbiased because its purpose is to illustrate the power of press freedom.
 * [WikiNews](https://www.wikinews.org/) is another outlet that doesn't publish frequently---because all its journalists are volunteers---but they occasionally put out a gem and the editable nature means that the community has a chance to correct for biases.

There are a few other sites that I *wanted* to include, but they either don't have current RSS feeds or there's something sufficiently non-standard about their feeds that I wasn't able to make them work.

 * [Freedom of the Press Foundation](https://freedom.press/) generally reports directly on press freedom.
 * [Global Voices](https://globalvoices.org/) is consistently a great entry point into world news, with most of the stories being personal in some way.
 * [National Oceanic and Atmospheric Administration](https://www.noaa.gov/news-features) has some of the best writing of the sites listed, here, so it's a shame that they haven't added RSS feeds to the new blog layout, yet.

If you [follow me on Twitter](https://twitter.com/intent/user?screen_name=jcolag) or watch the [Friday Twitter dump posts](/blog/tag/linkdump), you probably already recognize many of those news sources as those I actually read, myself.

So, it's mostly just straightforward news from various perspectives, with some science and technology news and editorials sneaking in.  I have to admit some disappointment that I wasn't able to find any republishing-ready entertainment or sports news.  I also find it interesting---and mildly disappointing---that there's no comparable news source with a conservative perspective; I wouldn't trust it, myself, given how much of conservative policy quietly derives from racism and has increasingly become a denial of fact, but I do feel mildly guilty that "all around" doesn't include a significant segment.

There was another batch of sites that I ignored, because they were based overseas, somewhere.  I figured that I could always think about expanding to multiple countries later.  Though several of the other sites are Iranian, so using them would probably (unfortunately, since they mostly seemed fairly credible) violate sanctions, somewhere, and that would lead to unpleasantness.

### One and a Half?

Did I mention the short URLs?  That's not quite ready to go, so I'm commenting them out until that server is ready to go.

Similarly, I should *probably* add analytics as I do on most of my sites, since selling advertising is likely going to bring up questions about visitors.  And eventually, I'll want to know which headlines and news sources "perform" better.

I'd also like to clean up the headlines, at some point, but most of them seem too erratic to bother.

## Phase Two

The next steps need to be to bring in money.  If the site can't afford to pay me to work on it for at least a few hours a month, there's no way that it'll get to the point where it's feasible to bring in journalists.  So, you might expect to see other ads on pages---though I refuse to compromise on them being mostly unobtrusive---and there's a good chance that I'll slap the site's logo on merchandise.  Those are the "big three" publication-funding models, after all:  Convince readers to pay, sell advertising space, and sell merchandise.

In hand with that, I'll want to advertise articles, to get more eyeballs pointing at the site.  The goal---if not immediately---is to automate this, because some sites post too frequently to handle manually.

Expect an **All Around the News** Twitter-bot, too, that will probably need to evolve after its release.

## Phase Three

If **All Around the News** becomes sustainable, the next goal will be to make the site friendlier to casual readers.  I haven't planned this far out, but options inspired by "real" news sites include the following.

 * Community interaction, whether that's a traditional "letters to the editor" page, the ability to comment on posts (which implies hiring moderators), or just a thumbs-up or thumbs-down on each article.
 * Comics, though---despite posting about [Free Culture works](/blog/tag/bookclub) on Saturdays---I haven't been able to find any comic strips with a long enough history to trust them.  There *are* comics with non-commercial licenses, but given that this is a commercial venture, I don't like that option, and don't like the prospect of trying to "game" the definition of non-commercial.
 * Puzzles, even something as simple as my own [daily nonogram]({% post_url 2021-02-21-nonogram %}) might be feasible, though newspapers when I was growing up also included other puzzles that might be interesting.  Procedurally generated crossword puzzles, of course, are a nightmare without a robust database of clues.
 * Weather, which is probably self-explanatory.
 * Search, but mostly because the search feature on most of the sites I'm borrowing from is a nightmare.

I would also like to consider "retiring" older articles, redirecting the URL back to the originals or to a permanent version of the Markdown stored on the Internet Archive, so that the database isn't carrying around content that nobody is likely to care about.  On the other hand, that would stymie the search feature.

In any case, that gives a frame to work inside.

## Phase Four

At this point, it'll be time to start trimming the under-performing news sources---there's one that I already suspect is going to be viewed as too much noise for too few good articles---and consider bringing other people in.

If the site is particularly successful in driving donations, I have some ideas about using the platform as a service to journalists.  But otherwise, trimming out the free content would allow space for work by newer journalists who have insights that might not be found at the larger outlets.

## Derailing the Phases

Of course, if someone wants to throw a bunch of money at me to buy **All Around the News**, because they want to start building their media empire, I'm probably not going to refuse the offer.

Alternatively, if I can't cover the price of the server and advertising after a couple of months, I'll probably leave the site open, but will need to stop putting work into it.

Meanwhile, if you've been looking for a news site that tries to treat readers with respect, give [**All Around the News**](https://allaroundthe.news) a try.  With any luck, it's a better experience than most news sites, with their clutter, paywalls, and context-breakers.

* * *

**Credits**:  The header image is just the **All Around the News** logo, which I'm willing to release under the blog's license for the sake of consistency.
