---
layout: post
title: Media Websites Wanted...
date: 2021-05-02 07:11:12-0400
categories:
tags: [rant, media]
summary: I consider websites that seem missing
thumbnail: /blog/assets/wanted-media-sign.png
offset: -20%
---

As I have been [reducing services]({% post_url 2021-04-04-cord-cut %}) and thinking more rigorously about my attempt at [ethical media guidelines]({% post_url 2020-08-02-ethmedia %})---along with some rethinking of what websites I read---that effort has spurred thought about websites that I would actually *like* to subscribe to or (if it has a better means of funding) just use, in order to help make other decisions.

![Wanted: Media Websites; BYO Reward](/blog/assets/wanted-media-sign.png "Wanted: Media Websites; BYO Reward")

As a content advisory, I'll need to hint at well-known instances of abuse and criminal activity in the entertainment industry.  I won't dig into the incidents or name names, but the links will identify the people in question and go into detail, and I will mention the categories of abusive actions.  So, if any of that information might be traumatic for you, please prepare yourself appropriately before seeing where any of those links go.

With that out of the way, on the off chance that someone ambitious decides to read this, here are some free ideas:  Just add business.  I haven't the foggiest idea to make them financially feasible, let alone profitable, though, so that's a big addition...

## Movie/TV Database for Ethics

We all presumably use one of the media databases---probably the one owned by Amazon, though the [Open Media Database](https://www.omdb.org/) has similar features and a Free license, if a less-complete database---to answer those pesky "why does that actor look familiar?" types of questions.  If you're not familiar with them and haven't visited OMDb, the idea is that you can search for movies, television shows, actors, crew, and so forth.  Each page is a list of links of either every project the person has worked on, or every person who worked on the project.  From there, you can (depending on how complete the database is) walk through the industry's various work relationships.

That's great for casual use, of course.  And I have to assume that, if you're a professional in the entertainment industry, it's probably extremely useful.  However, I want to see something more.

### Choices, Choices...

Specifically, I would like a site with a similar interface, but where each page also includes links to accusations, investigations, and criminal convictions for each person, company, and production.  I want to be able to look up a hypothetical movie and discover at a glance that---as a hypothetical conglomerated worst-case example---the financing was provided by company embroiled in a [multi-national embezzlement and money laundering scandal](https://en.wikipedia.org/wiki/1Malaysia_Development_Berhad_scandal) and led by [someone convicted of multiple sexual assaults](https://en.wikipedia.org/wiki/Harvey_Weinstein_sexual_abuse_cases); the production company [supplies dangerous surveillance technology used in human rights abuses](https://citizentruth.org/aclu-condemn-amazons-facial-recognition-tool-rekognition/), [is known for employing abusive people](https://en.wikipedia.org/wiki/Fox_News_controversies#Sexism), and occasionally tries to [scam writers](https://pluralistic.net/2020/11/19/disneymustpay/#disneymustpay) [out of royalties](https://pluralistic.net/2021/04/29/writers-must-be-paid/#pay-the-writer); the director has been repeatedly accused of [workplace harassment](https://en.wikipedia.org/wiki/Joss_Whedon#Accusations_of_workplace_harassment) and [sexual misconduct](https://en.wikipedia.org/wiki/Bryan_Singer#Sexual_abuse_allegations); governments were thanked for allowing [filming near concentration camps](https://en.wikipedia.org/wiki/Mulan_(2020_film)#Filming_in_Xinjiang) and [exchanging access to equipment and personnel for script oversight](https://www.defense.gov/Explore/Inside-DOD/Blog/Article/2062735/how-why-the-dod-works-with-hollywood/); the [star is violent and unreliable](https://en.wikipedia.org/wiki/Johnny_Depp#Personal_life); filming was plagued by [safety concerns](https://en.wikipedia.org/wiki/List_of_film_and_television_accidents); and the script is adapted from works by an author with [bigoted views](https://en.wikipedia.org/wiki/Politics_of_J._K._Rowling#Transgender_people) and a [history of abuse](https://en.wikipedia.org/wiki/Marion_Zimmer_Bradley#Child_sex_abuse_allegations).  Without that information, I admit that it's *possible* to scour entertainment news for every name attached to a project...and hope that a connection isn't missed or that multiple people with similar names aren't accidentally conflated.  But that's fairly difficult to make an informed decision on whether a particular movie or show is worth supporting.  Some information is on Wikipedia---clearly so, since that accounts for most of the links in this paragraph---but may be incomplete for people and companies that aren't sufficiently well-known among Wikipedia editors.  And the information certainly isn't organized with the purpose of connecting it by production.  I picked those examples because I already knew about them, not because I looked for them.

The upshot, though, is that I want to be able to quickly weigh the anticipated enjoyment that I'm likely to get out of watching something against the abuses that the production enabled.  I *might* see the list of abuses and decide that I'm willing to tolerate all of it, because the movie or show looks that good or important, or because the accusations are all in the past and don't seem to have panned out; in my personal case, I would then donate an equal amount of money to relevant charities, especially if I'm buying the thing on DVD.  I might particularly decide to tolerate abuses in the case of someone who died and/or whose works are in the public domain or released under a Free Culture license, since it's easier to separate the work from the creator knowing that supporting their work does nothing to support them.  But I might also say that the offenses are troubling enough or the show or movie isn't important enough to me that I don't want to compromise.  The key point, however, is that I can't make that decision without the proper information.

Again, I could plausibly do this work myself every time I want to watch or buy something, but that requires becoming an expert in navigating the entertainment press, so that I'm not relying on a creator being popular enough that somebody regularly updates their Wikipedia page.  It also stupidly duplicates the work of anybody else who wants the same thing.  Therefore, it'd be far better to have a centralized website take care of this.

### Possible Enhancements

A clever way to maintain this information would be something along the lines of how [Terms of Service; Didn't Read](https://tosdr.org/) presents the websites that it covers.  Each site is assigned a series of headlines that each link to supporting evidence.  Each issue is assigned user-friendliness level (shown by the color and icon) of neutral, good, bad, or so bad as to be a likely blocking issue for many people, which are then summarized with a [single-letter (A--E) grade](https://tosdr.org/classification).  I don't know if I would *like* that, since---unlike privacy---ethics is far more subjective, but it could also be a way to make such a database more approachable to casual readers.  For example, I would say that harassing colleagues is significantly worse than money laundering, and that turning a blind eye to ethnic cleansing is worse than both, but someone else might legitimately see money laundering as a broader breach of trust that can damage more lives than harassing people out of the industry could ever do.

Likewise, it doesn't need to be all *bad* news.  Charitable work and awards could easily be added to give a more nuanced view of the person or organization.  I happen to think that individual good actions never justify bad actions---after all, many abusers work hard to make sure that they have a great public image, specifically so that people will give them the benefit of the doubt---but a pattern of good actions can rebuild the reputation damaged by an old abuse.  And I know that many other people are willing to count up good and bad deeds.

Age might also be relevant to the analysis, especially when weighing good deeds against bad.  If an actor committed a crime when they were young, accepted the punishment, and has done good since, that's different from an actor committing a crime today.

At the core, though, I like to use food as an analogy.  Most packaging is required to show [nutritional facts](https://en.wikipedia.org/wiki/Nutrition_facts_label) about the contents, sometimes with strict guidelines.  Dietary restrictions of all sorts have certifications, with [Orthodox Union Kosher](https://en.wikipedia.org/wiki/Orthodox_Union_Kosher)'s Ⓤ-like symbol probably being the most recognizable in supermarkets, even if you've never stopped to think about what it represents.  Ethical certifications like [Fair Trade standards](https://en.wikipedia.org/wiki/Fair_trade_certification) also exist.  Most of us are aware of the egregiously unethical companies in the industry, like Coca-Cola, Nestlé, and presumably Bayer, given that they acquired Monsanto.  By comparing [mercury levels](https://www.fda.gov/food/consumers/advice-about-eating-fish), [sustainability](https://www.fishwatch.gov/sustainable-seafood/by-the-numbers), locality, and season, choice in eating fish can easily and even regularly is distilled down to wallet-sized cards.  But somehow, I don't know if I'm about to stream a TV episode that directly funds the defense for a murder trial or fascist insurrections, unless I spend an hour researching it.

### Likely Problems

Either way, it's probably obvious why this site does **not** yet exist:  There is no automation beyond the server itself.  Every accusation needs to be found, categorized, possibly confirmed, added manually, and tracked over time, since there is no algorithm that is going to figure out which articles are related and how.  That's all labor that requires a skilled, specialized worker.  I suspect that crowd-sourcing wouldn't work, unfortunately; it isn't Free-licensed, but looking at [Does the Dog Die? <i class="far fa-copyright"></i>](https://www.doesthedogdie.com/), it has a similar (though looser) model to TOS;DR or this concept, for identifying incidents that might traumatize a viewer.  But taking a look at a few entries turns up a fair amount of abuse, people seemingly inventing claims against popular movies from (especially) non-white directors.  I also hinted at problems with relying on Wikipedia, above, for people or works that aren't popular enough to get attention.

Unfortunately, such a site would probably find itself attacked by wealthy people in the entertainment industry---who would much rather silence a clearinghouse of their misdeeds---too.  We can safely assume that this is likely to happen, because Hollywood spent 2017 [blaming review-aggregation sites <i class="far fa-copyright"></i>](https://deadline.com/2017/05/pirates-of-the-caribbean-5-dead-men-tell-no-tales-baywatch-box-office-weekend-1202102887/) for poor box office numbers, somewhat ironic, given that the most famous of the sites in question is owned by two major studios and "review aggregation," by definition, only refers to reviews that have already been published.  Movie reviews have been around for a *long* time, film criticism seeming to date to 1908.  But imagine who they'd blame when a summer blockbuster flops, and it also turns out that most of the people involved in the film are terrible.

If anyone wants to risk it, though, I'd love to see it.

## Indie Hype

I don't know if there's a formal term for the field, but the "fan press" is huge.  If you want to find out what WarnerMedia is working on or what people thought about the latest release on Disney+, there are dozens---possibly even hundreds---of places where people are publishing their takes, in any medium that you might prefer to learn from, often daily.  If a [major film studio](https://en.wikipedia.org/wiki/Major_film_studios) was involved---directly or through one of their "independent studio" subsidiaries---it gets coverage, often so uncritical as to feel uncomfortably like unpaid advertising for companies that can afford to pay for their own advertising.

Missing from this ecosystem, as far as I can tell, is a similar excitement---even if it's more critical than coverage of mainstream releases---that talks about upcoming works from outside the United States, independent works (that aren't produced by formally "independent" studios just owned by a major studio), or creator-owned releases.  Personally, I'd exclude anime from that, despite clearly coming from outside the United States, given that there are plenty of mainstream "geek culture" sites that regularly cover the medium/genre, as well as everything else.  On the other hand, maybe that's just my disinterest in it showing.

Regardless, this seems like an easy win, because there are *plenty* of people looking for new things to watch and searching for ways out of the monopolistic ecosystems, particularly the increasing corporate reliance on remakes and franchises.  But despite that need for information, searching doesn't turn up anything persistent.  For example, it's not hard to find a site that bemoaned that the Disney investor call was all about sequels and prequels, but then turned around to spend two months praising every [**WandaVision**](https://en.wikipedia.org/wiki/WandaVision) detail, reinforcing the need for more sequels and prequels.  There doesn't even seem to be a streaming service dedicated to genuinely independent releases, as far as I can tell, but that's a problem for another day.

Again, I can see why this doesn't already exist:  Tiny production companies putting out a zero-budget web series or a deeply personal film don't have high-profile websites with press releases that get amplified in [**Variety**](https://en.wikipedia.org/wiki/Variety_(magazine)) or conduct press junkets that pass through all the morning and late-night talk shows.  Crowd-sourcing *could* be reasonable, here---it would be ideal to have producers submit information on what they produce---but that requires the site being known enough to be a standard part of small-business marketing, and it probably requires vetting contributions to make sure that the project is actually available and not a mainstream release trying to slip through.

## Bonus?  Media Use Tracking

This one, I *might* actually create, after talking about it in previous posts.

As I mentioned in my cord-cutting post, linked to up at the top, I briefly discussed how I tried to start quantifying the "effective" value of my assorted subscription services.  Specifically, I threw together a spreadsheet that took each of the subscriptions and specified the following.

 * Name;
 * Price per month, though I framed it as a cost and a period due to calculate it, so that I'm not dividing annual subscriptions by twelve on my own;
 * A rating between negative one and one, indicating how comfortable I feel supporting the company or creator; and
 * A calculated cost that multiplies the price by the rating.

As I mentioned in that post, if I ever do this again---and I probably will, eventually---then I'll almost certainly want to add a monthly entry for how much I *use* that particular service.  After all, the more a service is watched, the more we can consider it "necessary."  Necessity, of course, has effects on how to interpret the overall cost of the service.  That is, the cost per unit time watching Amazon Prime, for example, provides a value to weigh against the ethical concerns, so that it's not a one-sided analysis.  And in a case like mine, where I want to offset the money I spend on bad things, this is a clear signal to treat the service as something that demands spending on better media.

As an added service, an ideal version of this might profile the big-name streaming sites to help create those "ethical fudge factor" numbers.

The problem, as I see it, is in enabling users to maintain accurate watch-time information.  After all, while I can probably estimate how much time I've spent on a service in given month---I usually don't watch more than two episodes of anything per day, unless it's just night-time viewing to just have something on that I can ignore while I get ready for bed, so it's mostly just a matter of checking the continuing shows---but I certainly wouldn't log things as I watch them.  Importing the information might work, but getting access to watch history is increasingly tedious on some platforms and seems entirely absent on others.  It's been a long time since the days when Netflix and Hulu would happily just export a CSV file for your account whenever you clicked the button.

I do, however, like the idea of receiving a monthly e-mail comparing the value that each service has provided me, versus the financial and approximated ethical costs, along with a reminder when annual renewals are coming.  Seeing the balance of money spent on "good" media versus "bad" would also be useful.

So, like I said, maybe I'll just hack out a basic version and open it up to those of you who might want it.  I can figure out how to make to sustainable later.  But if someone else wants to do it first, I'm OK with that, too.

## Crossing the Vast Wasteland

In 1961, FCC Chairman Newton Minow gave his first speech.

 > When television is good, nothing---not the theater, not the magazines or newspapers---nothing is better.

He went on to explain that the majority of television, however, was a "vast wasteland" of formulaic sensationalism, boring stretches, and commercials.  He went on to give his view.

 > Television and all who participate in it are jointly accountable to the American public for respect for the special needs of children, for community responsibility, for the advancement of education and culture, for the acceptability of the program materials chosen, for decency and decorum in production, and for propriety in advertising.

And by the way, let's not forget that [advertising is obsolete](https://theconversation.com/advertising-is-obsolete-heres-why-its-time-to-end-it-101639) and destructive.

As it turns out, it's just a week short of sixty years later.  The last decade has seen some of the [best television in history](https://en.wikipedia.org/wiki/Golden_Age_of_Television_(2000s%E2%80%93present)).  But it has also seen some of its most banal, its most formulaic, and its most pointlessly sensationalist.  Commercials have also made a massive comeback, with fewer restrictions now that they're no longer always tethered to publicly owned airwaves.  [Media consolidation](https://en.wikipedia.org/wiki/Concentration_of_media_ownership) means that there's a decent chance that the movie you loved was produced by an awful company, while the [#MeToo](https://en.wikipedia.org/wiki/Me_Too_movement) and [#TimesUp](https://en.wikipedia.org/wiki/Time%27s_Up_(movement)) movements have brought abuses out of the shadows.

With these sorts of websites, we can empower each other to hold the participants accountable in ways that Minow didn't even imagine.  And while this is certainly a niche now, consider another analogy to food:  It's not that long ago that vegetarian cooking was a fringe practice, whereas today, there's a rush for companies to dominate the fake-meat market, because people learned to think about the ethics and effects on well-being of eating vegetables, while alternatives became more visible.

* * *

**Credits**:  The header image was constructed from the [Cowboy Collective](https://cowboycollective.cc/)'s [Wanted Poster Resource Pack](https://github.com/CowboyCollective/Wanted-Posters), released under the terms of the [Creative Commons Attribution 4.0 International](https://creativecommons.org/licenses/by/4.0/) license.  It includes an adapted version of [Wikipedia Homepage, Chromium Web browser 36](https://commons.wikimedia.org/wiki/File:Wikipedia_Homepage_Chromium_Web_browser_36.png) by [Enock4seth](https://commons.wikimedia.org/wiki/User:Enock4seth), released under the terms of the [Creative Commons Attribution-Share Alike 4.0 International](https://creativecommons.org/licenses/by-sa/4.0/deed.en) license, with the user interface parts of Chromium released under the terms of the [3-Clause BSD](https://opensource.org/licenses/BSD-3-Clause) license and Wikipedia content released under the terms of the [Creative Commons Attribution-ShareAlike 3.0 Unported](https://creativecommons.org/licenses/by-sa/3.0/) license.  If you want a vector image to pull the text from---but doesn't display well in browsers, otherwise I would've used it, instead, for accessibility purposes---you can [download it](/blog/assets/wanted-media-sign.svg).
