---
layout: post
title: Explaining Cryptocurrency
date: 2021-05-16 07:06:12-0400
categories:
tags: [rant, programming, money]
summary: A rundown, so that cryptocurrencies don't seem like magic
thumbnail: /blog/assets/bitcoin-money-decentralized-virtual-coin-currency-1435009-pxhere.com.png
offset: -16%
---

![Bitcoin, artist's rendition](/blog/assets/bitcoin-money-decentralized-virtual-coin-currency-1435009-pxhere.com.png "Bitcoin, artist's rendition")

You've no doubt noticed, over the last few months, that cryptocurrencies like [bitcoin](https://en.wikipedia.org/wiki/Bitcoin) have been increasingly creeping into the news, whether that's the [enormous cost of mining](https://www.ofnumbers.com/2018/08/26/HOW-MUCH-ELECTRICITY-IS-CONSUMED-BY-BITCOIN-BITCOIN-CASH-ETHEREUM-LITECOIN-AND-MONERO/), companies [inserting their own currency](https://pappp.net/?p=39868) in products, [non-fungible tokens](https://en.wikipedia.org/wiki/Non-fungible_token) being treated like news, the [volatility in the market](https://www.sciencedirect.com/science/article/pii/S1544612319309274), or the people seemingly getting interviewed so that they can push the [cryptoasset](https://fee.org/articles/three-key-differences-between-traditional-and-cryptoasset-markets/) rebranding so that people will stop asking silly questions about environmental cost, creation, and volatility.  And...look, I'll be honest, here.  People treat this stuff like it's magic, and nothing could be further from the truth.  So, I wanted to cook up something in straightforward English---or as close as I ever get to straightforward English---so that people don't get lost in the details or are forced to assume that they're missing something.

Full disclosure, I'm not a cryptocurrency cheerleader.  I toyed with the code when it was released, briefly invested about ten bucks on an exchange at a boring time, withdrew the cash, and that's pretty much it.  If someone wants to give me some, I probably won't turn it down.  My point is that I'm not going to explain why cryptocurrencies might be life-changing.  If you're looking for someone to tell you which coin to invest in, I don't have anything for you.

Instead, I'll explain that the central idea is to treat a [local currency](https://en.wikipedia.org/wiki/Local_currency) as if it was a mineral commodity like [gold](https://en.wikipedia.org/wiki/Gold_standard).  If you keep that in mind and understand a tiny bit of what we might charitably call "programmer culture," there's little to no mystery.  So, we start with that cultural touchstone, or rather the re-invention of it for this purpose.

## Yet There's a Blockchain...

When in doubt about the formal description of things, I find it useful to check if there's a [Simple English Wikipedia article](https://simple.wikipedia.org/wiki/Blockchain).  They aren't always ideal, but the introductions usually reliably introduce the idea in a more useful way than a conventional article or a dictionary entry.

 > A Blockchain is a method of storing a list of entries, which cannot be changed easily after they are created. This also applies to the list. This is done by using several concepts from cryptography, including digital signatures and hash functions.

The article then goes into a bit more depth on the math involved in *securing* the blockchain, but the point is that a blockchain is just a list, where it's easy to verify that nobody tampered with the list.  In programming terms, when we hear "list," we don't usually interpret it as the single-column, math-less spreadsheet that you might use for grocery shopping, but as a [linked list](https://simple.wikipedia.org/wiki/Linked_list), a way to organize data, so that each item tells you where to find the next item, for reasons related to how computers use memory.

![A linked list representation](/blog/assets/Singly-linked-list.svg "A linked list representation")

From a programming standpoint, that's *basically* all there is to it.  Your list is the set of transactions.  Everybody can have a copy of the transaction list, in this case, so that nobody needs to rely on a central authority to say which transactions actually happened.  And someone signs every little grouping of transactions (the "block"), so that anybody can verify that nobody changed the history.

I hear you asking "what's a hash function" in the back.  It's just some math that you can use to make similar-looking data look more distinct, and (ideally) not end up confusing it with something else.  A non-math version of a hash function would be a car's license plate.  Cars in a parking lot might be too similar to identify on sight, so many of us check the license plate number---a meaningless blob of text---when there's confusion.  If you're the snotty type about to tell me about your key fob, yes I'm old, but that key fob is sending out a meaningless blob of text looking for a response, so it's a similar idea.  If you're familiar with terms like [MD5](https://en.wikipedia.org/wiki/MD5), [SHA](https://en.wikipedia.org/wiki/Secure_Hash_Algorithms), or others, though, those are more direct examples.

### An Adoring Public

It's worth reiterating that every transaction of a cryptocurrency is---necessarily, given the goal of decentralization---in its blockchain.  While cryptocurrencies have a reputation for privacy, even a reputation for being used by criminals *because* of privacy, the public nature of the blockchain means that it's fairly straightforward to track the accounts of buyers and sellers, barring explicit criminal activity, such as money laundering.

The assertions of anonymity come from the fact that the accounts ("wallets") look like random numbers and that you can create as many as you please.  But unless you have particularly strange purchasing habits, it would take significant effort for a group of wallets to not have behaviors that indicate connections between them.

And once an investigator has an account or multiple accounts connected with a target, it only takes one data leak---deliberate or accidental---to expose a person's entire financial history on the blockchain.

Some cryptocurrencies have tried to add features to enhance anonymity, but no matter what you do (again, barring illegal actions), the problem is that the metadata is public, not that there's a strong link between the metadata and human beings.  If a wallet only ever takes money from one other wallet and only to instantly buy things, that's no more anonymous than using the original wallet.  If a thousand wallets all have their purchases shipped to the same address, *that's* no more anonymous than a single wallet.

On the flip-side, it's worth pointing out that the value of the blockchain is in its public accountability, where anybody could download a copy and audit it to validate that nobody has managed to cheat the system.  I mention this, because an astonishing number of corporate initiatives involve company-*internal* blockchains, which...at that point, just make a list.  Yes, technically it's a list where you can verify that all the entries are legitimate in some way, but if the list only comes from a central source, that source could easily rewrite parts of the list and re-authenticate it.  So, don't do that; it's useless.

## All That Glitters

Now that we have a sense of the technical side of cryptocurrencies, we can talk about the cultural side.  The short version is that they were designed to have a [libertarian capitalist](https://en.wikipedia.org/wiki/Right-libertarianism) ethos, where governments---and [fiat currencies](https://en.wikipedia.org/wiki/Fiat_money)---are dangerous, and the only legitimate authority comes from ownership, especially ownership of land and gold.  And in the abstract, gold has basically two properties when used as money.

 * Someone put work or money into mining the gold.
 * There's a finite amount of gold in the world, with each mining effort becoming more difficult as easier sources are exhausted.

You'll note the pseudo-mystical aspect of this, where the natural aspect and the effort *imbue* gold with value, rather than just accepting that people used pretty rocks for money and could have picked anything else; I'll give some famous examples of alternatives, later.  You'll also note the inherent inequality in the system, as you need to have sufficient needs met to have labor or money available---not to mention access to some plot of mineral-rich land---to dig.

The code simulates this mysticism by adding their coins to the system with each block of transactions, until the final coin goes out.  People can compete for the right to add that block to the list, and the winner can assign those coins as they see fit.  The analogy to mining is in the competition that results in a signature (which verifies that the block is authentic) satisfying some constraint.

### An A for Effort

If that sounds confusing, you *probably* deal with something similar every day that you ignore:  Credit cards.  Have you ever wondered how a website can tell you that you mistyped your card number without performing a transaction?  The numbers are created using the [Luhn formula](https://en.wikipedia.org/wiki/Luhn_algorithm).  If you take the first fifteen digits of the number, some quick multiplication and addition gives you (in the one's place of the result) the sixteenth digit.  If your card doesn't have a sixteen-digit number, there are only a couple of issuers where the final digit doesn't work the number of digits it does have.

Now, imagine if you needed to create a credit card number with a *specific* final digit, maybe for vanity purposes.  There's one quadrillion possibilities---10<sup>15</sup>, in most cases---for each final digit, so there are plenty of chances to get it right, but someone needs to test candidates until there's a correct answer.  That's not the entire story, though, because each issuer has an [identification number](https://en.wikipedia.org/wiki/Payment_card_number) ranging from one to eight digits, so your hypothetical card also needs to match one of those prefix codes to make sense...and that prefix might also determine how long the card number is.  You might also want to produce a "vanity number" using something like [calculator spelling](https://en.wikipedia.org/wiki/Calculator_spelling) with the remaining digits.  After all, if Google (376009), Jeff Bezos (50238), or even classic lifestyle columnist Heloise (3510734) wants to throw money at you for something entirely useless that nobody will ever notice, it seems reasonable to take it.

The math behind cryptocurrencies isn't remotely the same as this, but it should serve as a rough analogy.  You can hold a contest to see who can produce a "correct" number first, and you can change the puzzle's constraints to adjust the difficulty of that puzzle, in order to make the "mining" more difficult and take longer.  It's called [proof of work](https://en.wikipedia.org/wiki/Proof_of_work).

## Proof of Problem

The current discussion in media is that---since each calculation on a computer takes a tiny but real amount of electricity, many computers constantly performing many calculations with the intent of being the next winner in the blockchain library---this burns an absurd amount of energy, more than many countries.  Given that most of the world, especially with the lowest electricity rates, burns fossil fuels to generate electricity, it has climate activists up in arms.  Given that the price of bitcoin is higher than the cost to win them, people who support cryptocurrencies either don't care or try to explain why this is good, with particularly clueless billionaire CEOs who shall remain nameless (so that I don't accidentally summon their rabid fans) claiming that the resulting destruction "incentivizes" investment in renewable energy.  I suppose that it's like how hurricanes incentivize home renovations or burglary incentivizes television manufacture...

Anyway, that's really just a symptom of the deeper problem with cryptocurrencies.  Underlying the energy consumption---or any of the other problems---is that they're all systems where, by definition, the rich get richer.  The only way that you can satisfy proof of work constraints (more than accidentally) is to have more computers than your competitors *doing* the work.  It's not really "work" that's interesting, after all; the effort doesn't accomplish anything.  So, what you're really proving is that you can *waste* computational power.

It should be said that there are alternatives to "proof of work," but they're thematically similar, often directly rewarding waste or existing wealth, instead of using work as a proxy.  Therefore, these "friendlier alternatives" do a great job of showing that the environmental issues are just a small part of a more general mindset.

 * [Proof of stake](https://en.wikipedia.org/wiki/Proof_of_stake) randomly selects the next winner, with a chance of winning proportional to the number of coins you already have.  This is often explicitly justified by assuming that poorer people are a destructive force, having no "stake" in maintaining the current economic distribution.
 * [Proof of authority](https://en.wikipedia.org/wiki/Proof_of_authority) creates an explicit upper-class to serve as gatekeepers.
 * [Proof of space](https://en.wikipedia.org/wiki/Proof_of_space) and similar systems hold the same sorts of contests, but memory or disk storage is the feature being tested, rather than processing power.
 * Proof of burn (no Wikipedia page) requires the winner to irretrievably dispose of units of cryptocurrency---usually another one---before anyone else.

Even benign-sounding systems like [proof of personhood](https://en.wikipedia.org/wiki/Proof_of_personhood) advantage people who are more popular or outgoing, itself entailing a certain amount of privilege.  That is, a person just barely scraping by isn't going to have the time or money to visit a conference for someone to verify that they exist, whereas a wealthy person could plausibly hire dozens of proxies to set up bogus accounts for them.

In other words, for all the talk about famous or smart people working with cryptocurrency communities to make them "greener," the simple fact is that they're *predicated* on existing status or waste.  So, you can't program a fix into the system without upending the entire system.

## But Why?

The funny thing about this obsession with making money act more like a commodity and rewarding existing wealth is that---despite what many of us were taught in elementary school---there [isn't solid evidence](https://en.wikipedia.org/wiki/History_of_money) of money deriving from actual barter- or commodity-based economies.  Rather than some "intrinsic value," gold was used as money because monarchs said so.  So, it's all a weird nostalgia for a fictional, or at least exaggerated, time of glory.

It's also telling, though, that for all the utopian talk about entirely new economies, the design of all of these cryptocurrencies---even those used for universal income experiments---are still built around exclusivity and faith in the system.  In the latter case, the claim is that there's no need for trust, but it requires trusting the algorithms and the enormous mining/verification operations that could easily become cartels.  In fact, you'll notice that the first thing that people did when adopting the distributed, trust-less economy was to build centralized exchanges and trusted third parties.  That's actually accidentally similar to gold, where nobody reasonable would trust that a random gold coin is pure and the right weight, and therefore would need trusted assayers to validate transactions.

The space could be so much more than cheap copies of what already exists.  When I wrote about [politics in art and technology]({% post_url 2020-10-18-stories %}), I made the point that there's no more political act than creating something, because whatever we create puts our abstract values into concrete form.  We can make deliberate choices about what values our works represent, or we can pretend to be apolitical and allow our subconscious conditioning to show through, but we can't create without them.

So, cryptocurrency's mining *could* be cooperative instead of competitive, sharing the mined "coins" equally among all participants in the work.  The mining work could be productive, such as dividing up tasks from [Folding@Home](https://en.wikipedia.org/wiki/Folding%40home) or a similar system.  It's possible to pick new people rather than wealthy people, to *give* them a stake in the system, rather than insist that they prove they have one.  Or proof of stake could be a tax that goes to bringing new people into the system.  People could issue currency without mining as a promise to add a certain value to the economy.  Individuals could issue private currency *without* making any promises, which is valued by a ratio of how much other currency is earned to how much is in circulation.  People could issue currency however they like, but need to pay a high tax on transactions, if the community deems it excessive.  The "coins" could add and multiply non-linearly, making it less desirable to hoard money, and so making it less valuable to continue competing.  A system could even remake the idea of money entirely, something as strange as fixed units bound to an individual that can only ever be loaned for fixed periods of time, but never permanently transferred.

It all depends on the values of the specific creators and their community.

### Economies of Snail

Some readers might think that those (admittedly off-handed) ideas are nonsensical, but---as promised earlier---we live in a world where people have already used renewable or perishable resources as currency, from [snail shells](https://en.wikipedia.org/wiki/Cowrie#Monetary_use) to [decorative beads](https://en.wikipedia.org/wiki/Trade_beads) to [salt](https://en.wikipedia.org/wiki/History_of_salt) to [animal pelts](https://en.wikipedia.org/wiki/Red_squirrel#Historical,_cultural_and_financial_significance) to [weapons](https://en.wikipedia.org/wiki/Knife_money) to various foods.  In other cases, you might see [giant stones](https://en.wikipedia.org/wiki/Rai_stones) used without any literal transfers.  [Credit worthiness](https://en.wikipedia.org/wiki/Credit_score) is a huge counterintuitive factor in how much large purchases cost, effectively a second kind of currency.  So, the idea that there's some "natural" form of money is laughable, and even if it made sense, mainstream currencies need not be slavishly simulated when creating a new system.

In other words, once you move to a digital space and there are no existing rules, there's no limit to the possibilities.  It could be so much more than a list to reward whoever is willing to waste the most.  But what we have reflects the values of its creators, and they clearly value the possibility of wealthy, wasteful people getting the greatest rewards, regardless of whether they would phrase it that way.

## Don't Funge the Tokens

The other major element in the news, recently, has been the aforementioned non-fungible tokens.  Are you ready for an explanation of *this* magic?

They're like [property deeds](https://en.wikipedia.org/wiki/Deed), but they're encoded as transactions on a blockchain, usually [Ethereum](https://en.wikipedia.org/wiki/Ethereum)'s.  They're usually deeds of ownership for digital works.  That's the story.

The word [fungible](https://en.wiktionary.org/wiki/fungible) describes things that are interchangeable.  For example, while you *can* identify a dollar bill---and probably most other currencies---by its serial number and/or incidental damage over time, there's no instance where somebody needs a *specific* dollar bill in a transaction.  So, they're fungible.  As you can guess by the name, an NFT is *not* fungible; each one represents something different.

Someone issues (or "mints") the deed, and then can sell it.

Sure, there's some additional nuance, but that's it.  Like buying real estate, the deed gives you a claim of ownership, even if you're nowhere near the property, if it's legitimate.  Ownership may not be in all respects, such as mineral rights often being separate from property rights.  And an NFT can be effectively counterfeit, appearing functionally acceptable, but without any legal legitimacy.  Just because someone sells you a deed to the Brooklyn Bridge or to an acre of land on the Moon, it doesn't necessarily follow that you actually own what you believe that you bought.  But it might also be exactly what it appears to be.

## Tales from the Cryptocurrency

Despite my general skepticism, I suspect that this should provide enough information to understand what people are talking about when they talk about cryptocurrencies.

Cryptocurrencies try to treat their currency like mined gold.  They store transactions on a publicly auditable linked list, awarding their gold-substitute to whoever wins a pseudo-mining contest to add the next item to the list.  The overwhelming majority of those contests involve proving that contestants can afford to be more wasteful than any other contestant.  Those are all decisions made by the creators, rather than inevitabilities.

So...can we stop having podcast guests to "explain crypto" and podcast titles that are any phrase with an "NFT" acronym?  I have a fairly low bar for what passes as humor, and even *I* didn't try to name any part of this post "Nice, Fancy Thoughts" or whatnot...

#### <i class="fab fa-ethereum"></i>

* * *

**Credits**:  The header image is [untitled](https://pxhere.com/en/photo/1435009) by [Mohamed Hassan](https://pxhere.com/en/photographer/767067), made available under the terms of the [Creative Commons CC0 1.0 Universal Public Domain Dedication](https://creativecommons.org/publicdomain/zero/1.0/).
