---
layout: post
title: Free Culture Book Club — Ficly
date: 2021-05-22 07:06:12-0400
categories:
tags: [freeculture, bookclub]
summary: Discussing a selection of stories from Ficly
thumbnail: /blog/assets/writing-read-creative-white-time-old-738184-pxhere.com.png
offset: -13%
---

This week, our [Free Culture Book Club]({% post_url 2020-05-02-freeculture %}) reads selections from Ficly.

![Once upon a time...](/blog/assets/writing-read-creative-white-time-old-738184-pxhere.com.png "Once upon a time...")

To give this series some sense of organization, here are some basic facts without much in the way of context.

 * Full Title:  **Ficly**
 * Location:  <https://ficly.com>, stories specified below
 * Released:  2009 -- 2015
 * License:  CC-BY-SA
 * Creator:  Many authors, facilitated by [Jason Garber](http://sixtwothree.org/) and [Kevin Lawver](http://lawver.net/)
 * Medium:  Microfiction anthology
 * Length:  Mostly fewer than 250 words apiece
 * Content Advisories:  Coarse language, violence

This should go without saying---even though I'm going to repeat it with every Book Club installment---but *Content Advisories* are not any sort of judgment on my part, just topics that come up in the work that I noticed and might benefit from a particular mood or head space for certain audiences.  It's to help you make a decision, rather than a decision in and of itself.

Here are the stories we'll cover, today.  If any of them has prequels or sequels, I'll at least glance at those, too, regardless of author or rating.

 * [Your Destination Has Not Yet Arrived](https://ficly.com/stories/935) by [wordwill](https://ficly.com/authors/wordwill)
 * [I Drink Therefore I Am](https://ficly.com/stories/1246) by [lastsyllable](https://ficly.com/authors/lastsyllable)
 * [the so-called lucky survivor's lament](https://ficly.com/stories/1357) by [wilw](https://ficly.com/authors/wilw)
 * [Deep](https://ficly.com/stories/1456) by [Phil Plait](https://ficly.com/authors/badastronomer)
 * [In The Floorboards](https://ficly.com/stories/1875) by [Geebs](https://ficly.com/authors/geebs)
 * [Seduction in 3/4 time](https://ficly.com/stories/2274) by [YaYa](https://ficly.com/authors/yaya)
 * [In sickness and in health](https://ficly.com/stories/2721) by [Skull Man](https://ficly.com/authors/skullmandible)
 * [Six Word Challenges](https://ficly.com/stories/3077) by [John Perkins](https://ficly.com/authors/johnperkins21)
 * [Without Walls](https://ficly.com/stories/3572) by [Spiderj](https://ficly.com/authors/spiderj)
 * [Holden in Wonderland](https://ficly.com/stories/3870) by [Hobo Beard Bob](https://ficly.com/authors/hobobeardbob)
 * [Letter from Lisa: Sent 2009, received 2251.](https://ficly.com/stories/5030) by [ALRO613 (LoA)](https://ficly.com/authors/alro613)
 * [Young Gods](https://ficly.com/stories/5341) by [Eloquent Mess {(LoA)}](https://ficly.com/authors/eloquentmess)
 * [Tears On The Kitchen Knife.](https://ficly.com/stories/6813) by [Mighty-Joe Young (A.K.A Strong Coffee)(LoA)](https://ficly.com/authors/user-1171)
 * [Next Breed of Thief](https://ficly.com/stories/7320) by [ElshaHawk (LoA)](https://ficly.com/authors/elshahawk)
 * [I forgot](https://ficly.com/stories/7532) by [StudMuffin (LoA)](https://ficly.com/authors/studmuffin)
 * [Last Writes](https://ficly.com/stories/9295) by [Mostly Harmless](https://ficly.com/authors/mostlyharmless)
 * [<3?](https://ficly.com/stories/13108) by [bluefish](https://ficly.com/authors/bluefish)

They're short---the longest story I could find in the archive was just a hair over 250 words long---so this shouldn't take too long.

## Ficly

Here's how the Ficly team described the site.

 > Ficly is about creativity. When I was originally thinking about this idea, I was looking for something creative I could do for the last fifteen minutes of my lunch break before I jumped back into coding and writing documentation. I’d originally had an idea for a much larger site for serious fiction, but realized that most people don’t have the time to write serious fiction. But, everyone can carve out fifteen minutes to either continue a story someone else has started, or start something of their own --- something simple --- two, maybe three paragraphs of a character, a plot or even just a place.
 >
 > That’s the premise. We impose a limit of 1,024 characters because we think constraints are good. They make you choose your words more carefully. They also make it less daunting than starting at a never-ending blank screen in a word processor. All you have to do is write one kilobyte of something -–- something fictional. That’s all.

A small fraction of the stories (fewer than two thousand) are actually longer than the thousand characters, the longest being a bit more than twice that.

Ficly was an attempt to revive Lawver's prior [Ficlets](https://en.wikipedia.org/wiki/Ficlets) community at America Online, the [archive of which](https://ficlets.com/) is *also* free-licensed, though lacks the convenient database export that I'll talk about shortly.

They mostly shut down the interactive parts of the site in 2014, putting up the static archive, which is basically a large anthology that includes well over thirty thousand works of [flash fiction](https://en.wikipedia.org/wiki/Flash_fiction).

### Choosing the Stories

In case it's useful to someone else who wants to work with the Ficly archive, I want to briefly dig into how I chose the stories I did, which involves some math and some database code.  If that doesn't interest you, feel free to [skip to the compliments](#what-works-well), knowing that you aren't missing anything relevant to the stories themselves.

For those of you still reading, the Ficly website unfortunately isn't designed for new or casual readers.  I don't know any of the authors, didn't have a tag in mind, and didn't feel like picking random dates.  Fortunately, the maintainers posted their [database export](https://www.ficly.org/) used to create the modern site, so I downloaded it and imported the data into a local MySQL database to mess around with ratings to find the highest-rated stories available.  However, it quickly occurred to me that there's a difference in confidence between a story that one person says is great and a story that thousands of people say is great.  So, I took [this Math Stack Exchange answer](https://math.stackexchange.com/a/942965) and adapted it into my existing query.

```sql
SELECT
  resource_id
FROM
  ratings
GROUP BY
    score
  , resource_id
ORDER BY
  AVG(score) + 5 * (1 - EXP(-COUNT(score))) DESC
LIMIT 20;
```

It turned out that, at least for this data, the multiplier for the number of ratings doesn't affect the ordering for these top items by much, so it could be discarded, here.  I should also point out that this probably isn't the right solution for a *general* ranking; a story that everybody gave a bad review to is probably not better than a story with just one reader.

The `resource_id` points to entries in the `stories` table, which gives me the titles and---knowing that Ficly is a [Ruby on Rails](https://rubyonrails.org/) application---makes it easy to figure out the URL to each story to investigate.  If I was planning to develop this as an application, I'd `JOIN` this query to the `stories` table to just print the stories with titles, instead.  But since I don't have plans to go through the process again, let alone repeatedly for multiple users, it was easier to just go to each story's page.

Anyway, from there, I dropped the two stories that were written by an author already seen on the list and the one that isn't an actual story, to produce the list above.

## What Works Well?

Many of these stories---unsurprisingly, given that they were popular within the Ficly community---are excellent.  They know what story they want to tell, cram the important aspects into a space that would normally be an abstract summary for a longer story, and come out with something dynamic.  Constraints are often good.

Collaboration, in many cases, looks entirely seamless, with multiple authors piecing a larger story together over time without seeming to step on each other's toes.  In some cases, like *Next Breed of Thief*, this turns out as a linear story that could warrant being republished as a single unit.  In other cases, like *Your Destination Has Not Yet Arrived*, the result is a shared universe constructed from tiny vignettes.  Somewhere in the middle, you have *Without Walls*, that explores a universe in a possibly-linear series of steps.  There are obviously exceptions where a "sequel" is ignored by other authors, but that's fine, too.  I'd be interested in finding out if the original software was developed to make that cooperative writing easier or if the community just did it especially well.

There's also some decent variety in genre.  Science fiction is probably over-represented in these seventeen stories, but there are also many mundane "slice of life" stories, light fantasy, social satire, literary parody, mythology, and crime in there.  I didn't check, but my guess is that it wouldn't be hard to find high fantasy, war, historical fiction, or romance.  When glancing at the [challenges](https://ficly.com/challenges/), I also noticed collections of stories relating to superheroes, pornography, and holidays.  In other words, if you're a picky reader, there's probably *something* that will interest you in there, if you can find it.  Speaking of finding things...

## What Works...Less Well?

My biggest objection---as evidenced by my spending around a dozen ficlets' worth of text talking about wringing information out of the data---is the terrible interface of the Ficly website.  The only way to find something is to go through lists ordered by date, with no searching, curation, or alternative sort orders.  This tends to be a problem with *any* online anthology system, of course, and we've seen it before.  But usually, there's at least a top-ten curated favorites list or an option to get a list of randomly chosen stories.

More related to the storytelling is something made most clear with *Next Breed of Thief*, I think.  There are some stories that can't fit in this limited space.  Or, rather, the original specific story fits.  But the overall story arc it sets up then plods through dozens of pages, an unfortunate number of which contain some of the most tedious inter-event exposition that I can imagine, basically forgetting that each piece should be a complete story.

Finally, this is definitely a matter of taste, but several of the stories strike me as surprisingly clichéd given the high ratings.  The world, after all, almost certainly has more than enough zombie outbreaks, or parables about oppression where the twist is that there is no oppression, just someone who's a jerk.

## Opportunities

Probably none.  The Ficly community, like the Ficlets community before it, has been shuttered with only a static archive.  Nobody involved seems to be asking for money.  Everything is just there.

The code for the (current) Ficly site is on GitHub, though.  Maybe something can be done to improve that interface, by a sufficiently motivated reader, though I don't know how open the maintainers are to input six years later.

## What's Adaptable?

Just in the stories listed above and their prequels/sequels, there's an enormous amount of material.  *Your Destination Has Not Yet Arrived* introduces us to a world where geography is being scrambled in real-time, possibly deliberately, possibly dangerously, and possibly in an ongoing manner.  *I Drink Therefore I Am* and *Next Breed of Thief* build out different parts of a cyberpunk world, with the latter being particularly detailed.  As mentioned, *the so-called lucky survivor’s lament* and *In sickness and in health* both tell zombie apocalypse stories in their own ways.  *Deep* explores a common deal-with-the-Devil trope.  *Without Walls* provides nearly a dozen hidden cities that are bizarre in some sense, and a seemingly grizzled and lonely explorer who has been documenting his travels to them.  *Last Writes* provides the reclusive and quirky crime writer Vincent Crow and his dark secret.

There's more, but those are what stood out to me, in addition to a handful of named characters.

## Next

Next time, we'll read **Wilber & Co.**, a series of comic strips associated with releases of [the GIMP](https://www.gimp.org/) Free Software image processing tool.

While we wait for that, what does everybody else think about these "ficlets"?

* * *

**Credits**:  The header image is [untitled](https://pxhere.com/en/photo/738184) by an uncredited PxHere photographer, made available under the terms of the [Creative Commons CC0 1.0 Universal Public Domain Dedication](https://creativecommons.org/publicdomain/zero/1.0/).
