---
layout: post
title: Developer Journal, Early July
date: 2021-07-05 07:46:23-0400
categories:
tags: [programming, project, devjournal]
summary: Progress on assorted projects
thumbnail: /blog/assets/Fourth-of-July-fireworks-behind-the-Washington-Monument-1986.png
offset: -42%
---

I mentioned in [yesterday's post]({% post_url 2021-07-04-advisory %}), there's a part of me that wanted to use today to note the anniversary of [Bloody Thursday](https://en.wikipedia.org/wiki/1934_West_Coast_waterfront_strike).  But since I used that anniversary (a day late) last year---presumably not intending for the [developer journal](/blog/tag/devjournal) posts to continue forever---it seems silly to just repeat that.  And since I can't find any significant holidays or significant anniversaries...this is July.

![Independence Day, 1986](/blog/assets/Fourth-of-July-fireworks-behind-the-Washington-Monument-1986.png "Setting things on fire, near a body of water, to celebrate nationalism...")

In the United States, yesterday was [Independence Day](https://en.wikipedia.org/wiki/Independence_Day_(United_States)), of course---inexplicably always referred to as "the Fourth of July" by the same strident people who wring their hands about people saying "happy holidays" in December---but I'm trying to stop the day-late posts except in special circumstances.

However, if you have an hour or so, it's always worth learning more about [What to the Slave Is the Fourth of July?](https://en.wikipedia.org/wiki/What_to_the_Slave_Is_the_Fourth_of_July%3F) on or near the holiday, and there's a convenient version to listen to, courtesy of [LibriVox](https://librivox.org/).

<iframe
  src="https://archive.org/download/nonfiction037_1503_librivox/snf037_whattotheslavejulyfourth_douglass_pga_128kb.mp3&autoplay=0"
  width="740"
  height="44"
  frameborder="0"
>
</iframe>

While it's being passed around, this year, by anti-racist activists to explain why Black people aren't keen on celebrating the country's founding, it's far more valuable today for how Douglass calls out pro-oppression people cowering behind "Religious Freedom."

 > The anti-slavery movement [in England] was not an anti-church movement, for the reason that the church took its full share in prosecuting that movement: and the anti-slavery movement in this country will cease to be an anti-church movement, when the church of this country shall assume a favorable, instead of a hostile position towards that movement.

We see this problem repeatedly posed in modern culture.  Contrary to their teachings, many white religious groups embrace political choices that are misogynist (opposition to abortion and, to a large extent, sex work), homophobic/transphobic (literally anything involving gender or sexual minorities), and occasionally even racist (Mormonism wasn't really keen to admit the equality of Black people until relatively recently), then turn around to scream that progressive activists are trying to destroy their religion, even when people are largely just asking them to practice what their religion teaches them.

And that brings us to code.

## Stack Overflow

It occurs to me that I stopped talking about the occasional answers that I've written at Stack Overflow, at some point.  So, here's a quick roundup since the last one I mentioned, in case any of it is of interest to someone.  Apologies for the grammar of the questions, of course.

 * [C for loop, supposed to be able to omit initialization inside loop itself, doesn't work as intended](https://stackoverflow.com/a/62533282/3438854), June 23<sup>rd</sup>, 2020.  Short version, programmers will occasionally shoot themselves in the foot.
 * [C: realloc updates address of struct, but not addresses of pointers within struct](https://stackoverflow.com/a/63171586/3438854), July 30<sup>th</sup>, 2020.  Short version, memory management isn't fun in C.
 * [What props is for in this example](https://stackoverflow.com/a/64621229/3438854), October 31<sup>st</sup>, 2020.  Short version, not everything in code is useful to the computer.
 * [why doesn't char newWord[45]; have "clean" values at the start of a function like char newWord[45] = ""; does?](https://stackoverflow.com/a/64768263/3438854), November 10<sup>th</sup>, 2020.  Short version, C compilers probably don't initialize memory, but they might, and you shouldn't rely on either behavior.
 * [How to use * to include even dotfiles](https://stackoverflow.com/a/65760168/3438854), January 17<sup>th</sup>, 2021.  Short version---of what I actually called a "short version" in the answer---dot-files are terrible.
 * [How to run sed -i in sql](https://stackoverflow.com/a/67957290/3438854), June 13<sup>th</sup>, 2021.  Short version, many programmers don't know the difference between instructions and examples.
 * [Selection sort time complexity for array type data structure in C#](https://stackoverflow.com/a/68034207/3438854), June 18<sup>th</sup>, 2021.  Short version---again, of a so-called "short version"---working out an algorithm's complexity doesn't include worrying about your [Rube Goldberg](https://en.wikipedia.org/wiki/Rube_Goldberg_machine)-style implementation.
 * [How do I check whether an open port is TCP or UDP?](https://stackoverflow.com/a/68193885/3438854), June 30<sup>th</sup>, 2021.  Short version, communications protocols (may) assign port numbers to the interactions, but those numbers aren't relevant to any other protocol.  Amusingly, someone tried to "take me down" by misinterpreting what I said in order to claim it as wrong.
 * [how to grep columns from a txt file and redirect to another text file in shell script](https://stackoverflow.com/a/68223745/3438854), July 2<sup>nd</sup>, 2021.  Short version, UNIX/Linux systems have plenty of ways to treat text like a spreadsheet.

It seems like a lot, but keep in mind that this was just opportunistic answers written over the course of the year, because I forgot about including them.  If I paid more attention, there'd only be two.

Someday, I should probably write a post about why I started answering questions on Stack Overflow and whether I've actually learned anything useful since...

## Entropy Arbitrage

After only three weeks since [creating the repository]({% post_url 2021-06-14-blood %}), I took the repository private after realizing that hashed passwords are listed in the comment files.  As far as I can tell, nobody has actually cloned or viewed the repository, it probably only endangered me as the only user with an account, and I've since changed my password.

I'll be looking for a better way to *export* the comments, rather than just uploading them.  It's important, because I needed to delete a comment for violating the [Code of Conduct](https://john.colagioia.net/blog/coc/) rather extensively, and want a place to transparently describe those comments, so that it doesn't look like I'm hiding criticism.

In this case---until I find a more permanent way to store these moderation actions---an anonymous coward posted a small profanity-laden, misogynist, anti-Asian screed to the [Asian Women in Fiction](https://john.colagioia.net/blog/2021/03/21/asian.html) post, demanding that I hold Asian-Americans to a higher standard than the rest of the country.  The person also tried to object to my using the Civil Rights Movement and associated awareness of exclusion as a boundary.  It didn't add anything to the topic, and---as mentioned---didn't follow the few rules.

## Fýlakas Onomáton

Work continues on [**Fýlakas Onomáton**](https://github.com/jcolag/fylakas-onomaton).  The activation codes are now saved after being generated, and both activations and names are both tied to users.

I also updated a bunch of libraries.

## Next

This week should finish **Fýlakas Onomáton** and probably make it look like a reasonable service.  The big remaining feature---that I'm aware of---is finishing the activation, so that the device receives the requested API key.  And then the easier task is to just add API calls to the existing infrastructure, that are authenticated based on the API key.

Any time remaining will go to [**Doritís Onomáton**](https://github.com/jcolag/doritis-onomaton), updating it to match the activation process and use it to authenticate to the server.

* * *

**Credits**:  The header image is [Fourth of July fireworks behind the Washington Monument, 1986](https://catalog.archives.gov/id/6413316) by Ssgt. Lono Kollars, placed into the public domain as the work of an employee of the United States Air Force as part of their duty.
