---
layout: post
title: Amateur Stenography
date: 2021-11-28 07:25:00-0500
categories:
tags: [education, technology, opensource, typing]
summary: Starting a new hobby
thumbnail: /blog/assets/SOFT-HRUF.png
offset: -25%
proofed: true
---

![A SOFT-HRUF Splitography Writer](/blog/assets/SOFT-HRUF.png "It's not mine, but close enough")

From back when I started high school, I remember that the best investment of my time---other than volunteering in an office during my lunch period and getting exposed to one of the most supportive work environments I've ever seen---was taking a "word processing" class, basically the same typing class that had been taught for decades, except that the keyboards didn't weigh enough to snap a finger.  The teacher was great.  I made some of my first friends in the new area, there, though they were mostly graduating seniors.  But most importantly for our purposes, touch-typing at a decent clip makes it a lot easier to produce code and blog posts.  Even at a mere sixty words per minute, downright slow if compared to professional typists, I lose my train of thought far less than I do when I need to rely on slower input methods.  Oh, and I can also record information from second screens without needing to change focus.  All that from a class that I picked primarily because I didn't want to sit around in a study hall period during my freshman year.

Things can always be better, though.  I'm always going to think past where I'm able to remember to type, meaning that I'm always going to stumble when I forget what comes between what I'm typing *now* and what I had been thinking about typing *later*.  Plus, honestly, sometimes I just need to learn something new.

## Alternative Keyboard Layouts

At one of my first jobs, I experimented with keyboard layouts in hopes of seeing a boost in speed.  I set my home and work machines to use the [Dvorak](https://en.wikipedia.org/wiki/Dvorak_keyboard_layout) keyboard layout, for example.  I picked it up quickly, but didn't type any faster with it.  And since other people sometimes needed to use my computers, that experiment didn't last more than a couple of months.

I can't tell you whether switching to Dvorak will help *you*.  All I can say is that *I* didn't find any speed or comfort benefits, and the drawbacks---admittedly now obsolete, since it's rare for people to share computers, these days---when sharing a computer made it infeasible to dig deeper.

That said, I am still sometimes tempted to experiment with "Programmer Dvorak," which tries to arrange the numbers and symbols to be more useful to C-like languages, HTML, and CSS.

## Stenotype

{% imgr A stenotype machine from 1876|8637796793_ff20d6de7d_o.png|Old enough that it probably needs a PS/2 port... %}

As nice as standard touch-typing is, though, regardless of the keyboard layout, there's an approach to typing that's significantly faster at all levels that seems worth trying:  The Stenotype machine.

Other than seeing the old-style steel boxes used by court reporters, I never had any exposure to "machine stenography"---stenography itself includes [shorthand](https://en.wikipedia.org/wiki/Shorthand) systems---until a couple of fancy (but ultimately failed) crowd-funded open source keyboards appeared on various sites.  But critically, while professional typists with extensive practice and experience tend to peak at 120 words per minute, average stenotype students tend to *start* there, which is why stenotype machines are often used for court transcripts, closed captioning news reports, and so forth.  People tend to speak at around 120 to 160 words per minute, meaning that someone with some stenotype experience should be able to keep up with a typical discussion.

The system works by stripping down the number of available keys and combining---"[chording](https://en.wikipedia.org/wiki/Chorded_keyboard)"---them to produce words and syllables, which can be interpreted and transcribed by a person or computer.  Here's an example keyboard.

![steno-keyboard](/blog/assets/steno-keyboard.svg "The generic stenotype keyboard")

You will probably immediately notice that there are only twenty-three keys:  Four vowels along the bottom, seventeen consonants, and two symbols.  If you look closer, you'll notice that some consonants---S, T, P, and R---are repeated on both halves of the keyboard.  I'll explain why (somewhat) in a bit, but the idea is that some keys combine to make other sounds, such as the left-hand {% key TK %} (both keys handled by the left ring finger) stand in for a {% key D %} sound.

Some investigation on the topic of experimenting led me to [Plover](https://www.openstenoproject.org/plover/), where I realized that most keyboards don't have "N-Key Rollover" (NKRO), and so can't manage significant chording.  That includes my laptop's keyboard.  To solve *that* problem, I headed to the [supported hardware](https://github.com/openstenoproject/plover/wiki/Supported-Hardware) page on Plover's wiki to find a keyboard more appropriate to this experiment.

### Stenotype Machines

After checking out the options, I opted to buy myself a [SOFT/HRUF Splitography Writer](https://softhruf.love/collections/writers); `HRUF` is Plover's code for "love," which hints at how these systems are phonetic, and how they make do with so few unique letters.  Their keyboard, which is the same model as what you see in this post's header image, is admittedly a bit more expensive than some alternatives, but had some advantages that are important to me.

 * The product wasn't out of stock when I visited the site.  Some keyboards predict almost a six-month wait time, due to the various global supply chain issues that still haven't been resolved.
 * Each one ships pre-built, meaning that I wouldn't buy it with good intentions and then forget to assemble it.
 * Left and right hands are separate, which should make using them more comfortable.
 * It's open source hardware, with the design files [published to GitHub](https://github.com/molly/SOFT-HRUF/), so I'm supporting an ecosystem that I care about, and have enough information to make repairs, if the need arises.
 * Some superficial research on SOFT/HRUF's owner suggests that he's probably a pretty good person.
 * The purchase page is transparent about the cost of materials and labor.
 * The firmware has a mode and the hardware includes enough keys---by dividing the large stenography keys into normal-sized keys---that allows the continued use of a "normal" keyboard.

So, at least for me, it feels like the higher cost is likely to be worth it, even if I don't stick with stenography for the rest of my life.  The one significant downside is that the keys are laid out in a tight grid, meaning that my middle and ring fingers might have a bit more work to do than should strictly be necessary, but I can assure you that I've used worse...

It took more than a week to process the order, which is fine, considering that it's a private individual assembling things by hand at a time when supply chains have been falling apart.  Likewise, despite the fact that there's a pandemic and a Postmaster General who hates the Post Office, it shipped to my house in a few days.  Honestly, I expected the whole process to take to the end of the year.

I should mention that there are several other hobbyist keyboards out there, with different styles, levels of portability, and lead time necessary to build them.  If it's important to you, some are under various public licenses, and some are just proprietary.  So, if you're interested in trying this out, explore the space and compare the models.  Depending on how adventurous you are, you might also want to check the various crowd-funding sites, since they all almost always have a keyboard project or two "coming soon."  Alternatively, if you enjoy working with hardware and want to save some money, something like [Stenokey](https://github.com/mike-ady/Stenokey) will have you assembling off-the-shelf parts into a 3D-printed case.

So, I'm not endorsing anybody, here.  I'm documenting my decision, in case it's of use to anybody else.

## Stenotype "Theories"

Maybe oddly as we look at it from 2021, stenography hasn't been entirely standardized.  Instead, many systems---handwritten and mechanical---are built around phonetics, which (of course) varies based on accent and perception of that accent.  That's why spelling reforms always fail in English, but that's an entirely different discussion for another day.

The other aspect of stenotype systems is the chording, which attempts to reduce syllables to single strokes.  In this way, words might vary based on what sounds are considered more distinctive and---in cases where there are multiple instances of a letter on the keyboard---which hand takes a particular letter.

Combine these decisions, and we have what's called a "theory," which in the digital world, is easiest to think of as the thinking used to construct a dictionary.  In general, that's not *exactly* true, because older machines just punch a paper tape that later gets transcribed by a person.  But on a computer, there's the possibility of having the computer recognize the letters "HRUF" being typed quickly and (as mentioned above) actually inserting the word "love" into the current document.  This is why stenotype use is faster than traditional typing:  The hands type entire syllables at once, rather than one letter at a time.

In other words, part of stenography is something similar to spelling reform, though thankfully without the baggage of trying to convince everybody that English is only spoken in one way.

A dictionary is what will make this useful to me for *programming*, since I can take implausible keystrokes and have the software translate them into syntax in whatever programming language I happen to be using at any particular time, similar to [snippets](https://en.wikipedia.org/wiki/Snippet_%28programming%29) in an editor, assuming that I don't use that facility outright.  Some people give individual symbols names in their dictionaries, and others work with larger syntactic structures.

That's a problem for the future, however.  For now, I need to become functional enough to type regularly.  If, for example, I can't write blog posts or an e-mail, then I'm not going to use the keyboard nearly often enough to become proficient with it.

## Getting Started

In my case, setting up the keyboard is *almost* as easy as following the directions.  However, setting the keyboard to its "Tx Bolt" mode---whatever that actually means---opens a port on the PC.  But because I run Linux on my laptop, the port is opened without giving me permission to use it.

I'll need to figure out how to automate that.  Odds are, there's just a setting, somewhere, where the operating system will trust me.  But as long as I remember to manually update the permissions with `chmod`, I can use the keyboard without much trouble.  This is only a problem with Tx Bolt, by the way.  If I plug the keyboard in and have Plover translate, that will work fine.  However, doing that means that I need to turn Plover off to use my normal keyboard.

Next, I need to learn a stenography theory.  The aforementioned Plover is Free (Open Source) Software, so its theory is the most sensible target.  Conveniently, there's a Free Culture textbook for learning Plover, [**Art of Chording**](https://www.artofchording.com/).  It's incomplete, but I can always fill in the details, later.

In short, though, every chord is a subset of `#STKPWHRAO*EUFRPBLGTSDZ`, the aforementioned twenty-three keys.  Most chords are syllables, with the left bank of consonants being the "onset" sound, the vowels the...well, *vowels*, and the right bank the "coda."  So, {% key PA-T %} or `----P---A----------T---` (pat) is different from {% key -APT %} or `--------A------P---T---` (apt), because it changes which end of the syllable the {% key P %} would be heard.  In addition, some words and phrases are translations from abbreviations or "briefs," such as {% key EZ %} (easy), {% key UD %} (you'd), or {% key -FBG %} (of course).

Then, it's just a matter of practice, similar to learning to type on a traditional keyboard...except that the majority of the keyboard is the "home row."  Ten fingers straddle the edges between nineteen---remember, the left-hand **S** is double-sized---of the twenty-three keys.

Oh, and for what I hope are mostly obvious reasons, the typing isn't *entirely* phonetic.  Not every sound is represented on the keyboard, and English has a variety of words that sound similar enough to have the same stenographic representation.  So, a theory generally blends an approach to phonetics with certain words to be memorized instead of sounded out.

Speaking of the memorization, I should mention that, if you've watched closed captioning for live events like local news, stenographers produce those captions.  And if you watch regularly, you quickly see the memorization issues, where homonyms will occasionally sneak through, or what looks like a garbage string of capital letters occasionally shows up in place of an uncommon word or name.  Those are the equivalents of typos.

## And So Forth...

For me, the next step is drilling.  As I publish this---*not* typed on my Splitography, sadly, since I wrote a lot of the post before I had received the keyboard, let alone started learning---I'm about halfway through **Art of Chording** can awkwardly stumble through rudimentary typing, and gaining some confidence, which is roughly where I was when I started touch-typing.

From here, I should really print the above abstract image of the keyboard with letters for reference, so that I don't need to guess and delete wrong guesses.  Then, it's just a matter of committing some time every day, probably only fifteen to twenty minutes, to getting the practice I need.  Once I can test at close to thirty words per minute, I'll make it my primary keyboard and build from there.

This always goes---or should go---without saying, but especially here, feel free to share your own experiences with stenotype systems if you have them.  And while I'm just starting out and so might not be useful, I'll be happy to try to answer any questions people might have.

* * *

**Credits**:  The header image is [SOFT-HRUF](https://commons.wikimedia.org/wiki/File:SOFT-HRUF.jpg) by [GorillaWarfare](https://commons.wikimedia.org/wiki/User:GorillaWarfare), made available under the terms of the [Creative Commons Attribution 4.0 International](https://creativecommons.org/licenses/by/4.0/deed.en) license.  [Stenotype](https://www.flickr.com/photos/paille-fr/8637796793/) by [Paille](https://www.flickr.com/photos/paille-fr/) has been made available under the terms of the [Creative Commons Attribution Share-Alike 2.0 Generic](https://creativecommons.org/licenses/by-sa/2.0/) license.  The stenotype keyboard layout is adapted from images used throughout [**Art of Chording**](https://www.artofchording.com/), available under the terms of the [Creative Commons Attribution Share-Alike 4.0 International](https://creativecommons.org/licenses/by-sa/4.0/deed.en) license.
