---
layout: post
title: Ubuntu Scrolling Woes — Small Technology Notes
date: 2022-01-12 07:20:05-0500
categories:
tags: [techtips, linux]
summary: Opaque features sometimes change
thumbnail: /blog/assets/work-technology-vintage-wheel-retro-clock-606288-pxhere.com.jpg
proofed: true
---

Once in a while, I have a small problem with some regularity that has an easy solution.  Traditionally, I write a note to myself, somewhere, and then need to hunt down the note when I need it next time.  Since that’s inefficient, whenever I have one of these, I now use them as short blog posts.

![Gears](/blog/assets/work-technology-vintage-wheel-retro-clock-606288-pxhere.com.jpg "Fiddly technical things ahead")

In this case, I have finally found a solution to a problem that has nagged me for a couple of years, at this point.  At some point, something in Ubuntu changed.  I don't know exactly when, but when clicking the scrollbar in an application, the scrollbar's "thumb" jumps to that location, so that scrolling by screen-sized "page" only works by keyboard *if* that panel has focus.  Normally, it's not much of a problem; the keyboard works in many cases, and I don't generally need sophisticated scrolling.

That said, when I'm working with an application with multiple panels where clicking anywhere might have an effect---I'm thinking of [Tweetdeck](https://tweetdeck.twitter.com/), especially, which I use to read Twitter---it's frustrating to have the scrollbar jump the page view so erratically.  I ended up using a Chromium-based browser for just those rare sites.

Searching---annoyingly difficult, because the terminology isn't entirely standard and, where it is standard, is instead obscure enough that people asking or writing about it might not have it right---turned up [this Ask Ubuntu question](https://askubuntu.com/questions/295988/how-to-fix-gtk3-scrollbar-behavior), which provided two out of three solutions.

In `~/.config/gtk-2.0/settings.ini`, add or fix this value.

```ini
[settings]
gtk-primary-button-warps-slider=0
```

This took care of Firefox.  Meanwhile, in `~/.config/gtk-3.0/settings.ini` and `~/.config/gtk-4.0/settings.ini`, the setting changes.

```ini
[settings]
gtk-primary-button-warps-slider=false
```

Voilà.  Now, everything should work correctly, after a restart...unless another GTK version has been released since I last updated this.  I imagine that someone who needs later versions could monitor [the relevant GTK documentation](https://docs.gtk.org/gtk4/property.Settings.gtk-primary-button-warps-slider.html) for the appropriate setting values and (I would have to hope) any new settings that might replace this one.

It's a bit silly to jump through these sorts of hoops, but it's all admittedly less tedious than constantly clicking too far, triggering an auto-load, and then having trouble finding where I left off.    Obviously, a better solution would be for [GTK](https://gtk.org/) to make such a non-traditional change in default behavior.  It's a bit late to fix that side of things, though.

## That's Not All...

Another significantly irritating issue that I've had is that, on *some* websites---again, Tweetdeck is an example---some `textarea` controls on the page will lose focus when hitting the {% key CTRL %} key.  Unfortunately, there's an easy solution to this, but it requires turning off one of my favorite features:  Showing the mouse pointer location when hitting that {% key CTRL %} key.

It's one of the first things that I generally turn on in an operating system.  If you're on Linux, you can find it listed in the **Gnome Tweaks** application.  I suppose that I can turn it off when using a problematic page, then turn it back on.  That's probably fine, if annoying.

* * *

**Credits**:  The header image is [work, technology, vintage, wheel, retro, clock](https://pxhere.com/en/photo/606288), by an anonymous PxHere photographer, is made available under the terms of the [CC0 1.0 Universal Public Domain Dedication](https://creativecommons.org/publicdomain/zero/1.0/).
