---
layout: post
title: Developer Journal, New York Public Library
date: 2022-05-23 06:47:05-0400
categories:
tags: [programming, project, devjournal]
summary: Progress on assorted projects
thumbnail: /blog/assets/51396225599_18974b261a_c.png
proofed: true
---

Today marks the 127<sup>th</sup> anniversary of the formal founding of the [New York Public Library](https://en.wikipedia.org/wiki/New_York_Public_Library), an institution that has chosen to respond to the nation-wide movement to ban books---that just *happen* to showcase protagonists or situations that involve non-white or non-Christian people---by offering teens across the country a [one-year digital library card <i class="fas fa-copyright"></i>](https://www.nypl.org/spotlight/books-for-all) to circumvent those bans.

![The front entrance of the NYPL's Main Branch](/blog/assets/51396225599_18974b261a_c.png "I wanted a picture with the lions, forgetting how small and far apart they sit, relative to the space...")

Read about some programming adventures, then go get your library card.

## Entropy Arbitrage Mailing List

At the beginning of the month, I described [potential future problems with Mailchimp]({% post_url 2022-05-02-may %}), and mentioned that I would probably look for an alternative.  In addition, I half-heartedly ran a raffle in the [*Real Life in Star Trek* posts](/blog/tag/startrek) to direct people to my Buy Me a Coffee account if they wanted to throw a few dollars my way, which [flopped last week]({% post_url 2022-05-19-farpoint1 %}#raffle-results).  I also never really warmed to Mailchimp; Intuit bought them, and never---to my knowledge---made an announcement about the March data breach, both of which undermine reasons that I chose it in the first place.

None of these represent a *crisis* on their own, but they all indicate a potential problem.  Mailchimp hasn't changed its service tier structure, yet, but it almost certainly will drop its free API, eventually.  A failure to entice anybody to help me fund my largest project doesn't put me in financial jeopardy, but it does increase the odds that I'll need to eventually skip a post to do something that earns money, and I don't like that.  And while I realize that we sometimes need to tolerate handing mind-share to unpleasant monopolists, the fact that Intuit coordinates with its competitors to lobby Congress to keep tax preparation far more complicated than the IRS could easily make it.

I worried about these issues a bit, and then I remembered the best advice that I've ever heard, from Pulpy science fiction.

 > If you have a few problems, you have trouble, but if you have a whole lot of problems, they start solving each other.

You can find the source for yourself, if you want, but I'll probably want to do something with those stories, someday.  Regardless, I love the line, and it *might* have inspired the name of the blog:  **Entropy Arbitrage** (in my eyes) referring to the idea that we can't stop things from falling apart, but we can sometimes redirect collapses into somewhere that it brings value.

In any case, I realize that I took the long way around this story, but...well, I also like the Blaise Pascal line, often attributed to Mark Twain.

 > I had not made this longer than the rest, but that I had not the leisure to make it shorter than it is.

Despite the stalling, I do have a solution.  Or rather, my problems solved each other...by giving me slightly more work.

I have a plan---already in progress---to start supplementing the mailing list *with* [my Buy Me a Coffee ☕ account](https://www.buymeacoffee.com/jcolag/).

### Phase One

A few days after the "real" newsletter issue goes out, my Buy Me a Coffee "followers"---no money involved---will get a copy of the newsletter.  People subscribed to the Mailchimp mailing list will continue to receive it normally.

### Phase Two

My followers will also see announcements for blog posts as I publish the posts, for people who don't have an RSS feed reader handy and don't want to wait for the monthly roundup.  You can already see this in action, by clicking on *Posts*, so I guess that this technically qualifies as the first phase, but you can consider the feature "in previews," just now.

### Phase Three

People who contribute monthly will also receive preview versions of what I write in the newsletter.  If you want to know what I thought about [**Haunted Heroine**](https://amzn.to/3wp5Gdb), but don't want to wait until June 4<sup>th</sup>, I posted that there already.  Do you want this month's people-search issues before the rest of the world?  That will probably go out later today or tomorrow, after I actually do the work.  I only started this plan on Friday, so I don't have much up, but it should give a general idea.

### Phase Four

I'll rethink the support tiers.  I chose five and ten dollars, because I thought of using the platform for [All Around the News](https://allaroundthe.news/), rather than my work in general. Five dollars averages something less than twenty-five cents per post, if you join to support me as a "member" on the basis of supporting the blog, but I'd rather not exclude people or make this into a project *about* money.

Plus, I can always find additional value for more expensive tiers, for people with deep pockets.  Would members have an interest in a Matrix room or Discord server?  Would they want to schedule a monthly video chat?  Monthly postcards?  Occasional raffles?  If I have enough people asking for it, and if it doesn't create a time sink that takes me away from other things, I can at least consider it.

I'll also see if I can do something for "Supporters," the people who make a one-time contribution.

### Phase Five

When Mailchimp eventually makes itself a problem in my life---it probably won't happen *soon*, but it will definitely happen, eventually---then I'll send out one final newsletter directing everyone to Buy Me a Coffee as a replacement, and shifting the final newsletter release back to Saturday.

### Summary

I mostly like this.  It gives me a backup system, to hedge against the eventual time when I need to stop using Mailchimp, either technically or ethically.  It provides a mild enticement, for people who already might have wanted to help support this work.  The problems solved themselves.

Therefore, [**Buy Me a Coffee**](https://www.buymeacoffee.com/jcolag)...*if you dare*. ☠ No pressure.

I do have one minor issue:  It doesn't look like Buy Me a Coffee has an API, yet.  That means that, at least for the duration, I need to remember to post there manually, instead of just adding it to my existing scripts.  But I have a support ticket in for it, and can always write some code to operate the site in a headless browser, or something, if they take too long.  If I do, I'll post about that adventure, here.

## Salavi

{% github jcolag/salavi %}

A fair amount of the week went to making the snakes and ladders visible on the page.  I considered trying to draw them manually, but eventually decided to give the [LeaderLine](https://anseki.github.io/leader-line/) library, instead, to minimize the maintenance work.  Plus or minus a few options, you give the library a DOM element to start and end the line, and it draws it.  With the options, I can have the "snakes" animate and keep the colors distinct.

I also made a couple of changes that mostly qualify as superficial.  However, giving the game board a DOM ID might ease something in the future.

Oh, I also ran some experiments on a library, but it didn't do what I needed, unfortunately, so I never committed those changes.

## Library Updates

I needed to bump library versions for [**Zoea**](https://github.com/jcolag/zoea) and [**Fýlakas Onomáton**](https://github.com/jcolag/fylakas-onomaton).

## Next

**Salavi** still needs its secret adversary.  I experimented with a certain JavaScript library that has recently gotten a *lot* of good press, but it didn't work for me, and I don't want to spoil the new feature before I have it implemented...

* * *

**Credits**:  The header image is [New York Public Library- Main Branch](https://www.flickr.com/photos/ajay_suresh/51396225599/) by [Ajay Suresh](https://www.flickr.com/photos/ajay_suresh/), made available under the terms of the [Creative Commons Attribution 2.0 Generic](https://creativecommons.org/licenses/by/2.0/) license.
