---
layout: post
title: Developer Journal, María de Zayas
date: 2022-09-12 07:34:05-0400
categories:
tags: [programming, project, devjournal]
summary: Progress on assorted projects
thumbnail: /blog/assets/MariadeZayas.png
offset: -17%
proofed: true
---

Today commemorates what people seem to vaguely agree on as the 432<sup>nd</sup> birthday of [María de Zayas y Sotomayor](https://en.wikipedia.org/wiki/Mar%C3%ADa_de_Zayas), one of the modern world's pioneering novelists.

![A sketch of María de Zayas from del Siglo de Oro](/blog/assets/MariadeZayas.png "Anybody who riffed on Cervantes qualifies as a friend in my book...")

And with a lack of legitimate holidays, let's look at some software.

## Wasting Time with Firefox

Thursday morning brought an "exciting" change to [my homepage](https://john.colagioia.net).  I spent an hour or two trying to figure out why the CSS that I saw had little to no connection to the CSS served.  I finally narrowed it down to the browser itself, and from there one of Mozilla's own add-ons, the built-in Facebook container.

The problem?  They updated the add-on to override CSS, changing fonts and colors with their own branding.  Searching for those CSS changes found me [the GitHub issue](https://github.com/mozilla/contain-facebook/issues/857), where a developer explains that...they released something buggy.

And yet, I have to wonder if the Firefox team still cares about the product.  For the last few months, I've had tabs *and* the application crash regularly, up until recently, with no way to figure out why.  And you might remember [last year]({% post_url 2021-08-02-generic %}), when *the same add-on* started flagging [every e-mail submission as stealing data for Facebook](https://github.com/mozilla/contain-facebook/issues/783)...except on *their* web pages.

Taken as a whole, it would feel like Firefox wants to spread distrust of the web, except that they don't have anybody proposing an alternative system to push people to.  That, and they have such a small market-share that any attempts to sway public opinion don't have much chance of success.  Instead, they only seem to undermine their own credibility to no benefit, except maybe Google's.

## Iungimoji

{% github jcolag/iungimoji %}

The game's page now links to [the archive](https://jcolag.github.io/iungimoji/), stowed in a `footer` element that *tries* to have the correct positioning on the screen.

Somewhere along the way---I want to say that it had something to do with fixing the `footer`, but that doesn't make much sense---the grid of tiles stopped centering.  To fix that, the board now has a left margin that varies with the size of the board.

I also updated the documentation to draw the distinction between the game generator and the game page.

## Miniboost

{% github jcolag/Miniboost %}

The big deal, here, involved allowing the user (me) to specify a temporary folder, to avoid the issues that I mentioned [a couple of weeks ago]({% post_url 2022-08-22-haiti %}) with the Firefox Snap.

Rather that handle this in code, it sets the `$TMPDIR` environment variable before running the **Miniboost** code, exactly like it sets `$NODE_OPTIONS` to `--openssl-legacy-provider`, as I discussed [back in February]({% post_url 2022-02-07-cripple-creek %}) to avoid a then-mysterious crash.

## CPREP

{% github jcolag/background-generator %}

I had the code open for my strange little background generator open, since I've wanted to start setting it up to run on GitHub Pages.

Rather than doing anything along those lines, though, I happened to page through a generic Free-licensed role-playing game supplement---reviewing it for an unrelated project---and noticed a comment in the introduction that it would use ze/zem/zir pronouns in all cases that didn't involve a specific gender.

As you might already know, I have kept a rule for this project that it can't use terminology that doesn't see use in public domain or Free Culture works.  To my research, ze and its other forms didn't exist prior to 1996, so I have avoided adding them to the software.  Yes, I know that you can't copyright words, and that people intend for people to *use* new pronouns, implying a public license even if copyright law applied.  However, the rule seemed and still seems reasonable for this sort of project, so it gratified me to find a source---licensed CC-BY-SA---using that set of pronouns regularly and consistently.

While I had the file open, I also added a/am/ar---used by [John of Trevisa](https://en.wikipedia.org/wiki/John_Trevisa)---and ou/oun/ous, recorded by William H. Marshall in 1789.

## G.L.O.B.E.

{% github jcolag/g-l-o-b-e %}

This might become slapstick comedy at any time, as I make changes that will show up on the server as I make them...

Specifically, I have started work on creating a path to starting a new game, for the rare person who wants to play more than once per day.  I haven't finalized the code or created the interface, yet, but the "new game" only amounts to a seed that includes the time of day, in addition to the date.  If the player hasn't specified a date---which overrides everything else---and has a seed mentioned in the browser's local storage, then it uses that as a seed instead of the date.  This required changing when the dates become text.

Oh, and it also needed an extra condition.

```javascript
if (stext.indexOf(when) >= 0) {
  when = stext;
}
```

For those of you who don't have much familiarity with JavaScript or the internals of **G.L.O.B.E.**, the seed text usually looks like the date.  For example, you might find today's seed as `Mon Sep 12 2022`, whereas the seed for additional games might look like `Mon Sep 12 2022 15:58:18 GMT-0400 (Eastern Daylight Time)`, adding---or, rather, not dropping---the time of day.

Because the two seeds start with the date, the code can identify when the seed comes from a previous day.  We do that with `indexOf`, asking if the run-time can find the shorter seed within the longer seed.  If it can, then replace the shorter with the longer.  If it can't, then we have a new daily game to show, which takes priority.

In any case, as (most of) a first step, it feels too heavy-handed to me, but right now, we now have a "modal" panel for configuration, adapted from [**Mystic T-Square**](https://github.com/jcolag/mystic-t-square), which creates a new seed an---the heavy-handed part---refreshes the page to allow the player to start the new game.

## Library Updates

I needed to bump library versions for **Miniboost**, partly to resolve a strange merge issue that wouldn't go away by merging.

## Next

I'll continue changing **G.L.O.B.E.** to manage these new games, starting with the CSS file that I apparently forgot to commit, yesterday.  Once I've finished that, I'll make comparable changes to **Iungimoji**.  If I have time, I'll figure out how to handle the page-refresh better, and think about adding other configuration options, like the date for historical games, **G.L.O.B.E.**'s language, and the **Iungimoji** game size.

* * *

**Credits**:  The header image is [María de Zayas y Sotomayor](https://commons.wikimedia.org/wiki/File:MariadeZayas.jpg), long in the public domain.
