---
layout: post
title: A Gentle (and Biased) Guide to Mastodon
date: 2022-11-20 6:51:03-0500
categories:
tags: [freesoftware, mastodon, socialmedia, twitter]
summary: Explaining the site without jargon or euphemism
thumbnail: /blog/assets/Knight-Mastodon.png
offset: -15%
update: [
  '2020-01-18-fediverse.md',
  '2022-05-01-twitter.md'
]
proofed: true
---

I know, I know.  Due to [Twitter's new management]({% post_url 2022-05-01-twitter %}) not seeming to have any idea of how the Twitter ecosystem works beyond his sycophantic followers, you want to try your luck with social media that maybe doesn't have corporate overlords.  I get it, and I support it.  I even started this blog with a [series looking at the major Free Software social networks](/blog/tag/socialshowdown), and long-time readers can consider this an adjunct to my post about "[the Fediverse]({% post_url 2020-01-18-fediverse %})."

![A reconstruction (painting) of an American mastodon](/blog/assets/Knight-Mastodon.png "Let's talk about the elephant in the room...")

Changing presents (some people) a problem, though:  Mastodon (or whatever; we'll get to that in a bit) doesn't and shouldn't exactly replace Twitter, in the same way that Twitter doesn't replace Facebook, a 1980s dial-up bulletin board, or a common room in a dorm.  You can use them for overlapping things, but if you treat one exactly like another, it'll disappoint you.  This, then, will try to help walk you through the differences in how things work and how the culture necessarily differs.

## Twitter in Review

Before we get to the real material, let's take a look at *Twitter*'s structure, and how that affects what people post, something that most people don't bother to think about much.  If this feels too superficial to you, one of my first posts on this blog discussed [why social media makes us angry]({% post_url 2019-12-20-social-media %}).  It goes into more depth and has some illustrations, though probably hasn't gone through as much proofreading as it should have.

In short, though, sites like Twitter run on advertising money...assuming that advertisers don't completely abandon it after recent erratic behavior, at least.  A site can increase the rates that it charges for ads, if it can serve those ads to a receptive or trusting audience.  You can make people more trusting by wearing down their emotional resistance.  You can wear down people's emotional resistance by making them emotional.  Emotion-wise, we can most reliably provoke anger and fear.

This model explains why local news focuses on any crime that they can scrounge up, television shows go to commercial on cliffhangers, [cable news wants you to fear everything]({% post_url 2022-10-30-fear %}), and why social media never removes right-wing views unless they repeatedly outright break the law.

For social media, it also explains why popular social media gamifies everything in a way that incentivizes you to say the most extreme things that come to mind.  It dangles hopes of "going viral," so that you'll try to stand out, and you stand out by going further in your positions than you normally would.  Because of this, you find people who advocate for prison abolition talking about how we need to throw these other people in prison, or people who won't shut up about loving freedom turning around and advocating for a police state.

I want to establish all this up front, so that we can refer to it again, later.  The structure of a website strongly influences its culture, and the company's business model will influence that structure.

## Introducing Mastodon...and Friends

Now that we understand Twitter better, we can take a look at Mastodon.

On the surface, you see many of the same features.  You sign up *somewhere*---we'll talk about that in a bit---and sign in.  From there, you get an interface that lets you search for people or words, a place to (ahem) "toot," the list of "toots" from people who you follow, and a list of notices, for the most part.  Change "toot" to "tweet," and you should have the ability to jump in, once you sign up.

You then have some features that help you learn more about the community, links to see *everything* happening, like Twitter's old "fire-hose" features.  In most cases, you separate that between your server and the whole network.  And that reminds me that we need to talk about...

### Different "Homes" (Servers)

When you go to sign up, you find the first big different from Twitter.  One company owns Twitter.  You go to *the* Twitter website, and you sign up.  Mastodon's providers trend less towards well-funded Silicon Valley concerns and more towards independent people entertaining themselves, and the occasional social group.  And so, their goals tend to affect the character of the server, by affecting who signs up there.

You need to find a server, here.  You can care about this decision as much or as little as you like.  The stakes don't raise particularly high, because with some exceptions, you can move to a new server if you don't like where you landed, and even the worst possible choice still lets you communicate with everyone else using Mastodon.

If you want to carefully research this decision, pick a large or curated list of servers like [Mastodon Instances](https://instances.social/) or [Fedi Garden](https://fedi.garden/)---you'll sometimes see terms like "instance" or "pod," which largely depend on how programmer-oriented or stylistic the speaker/writer feels---and check for servers for people with your interests.

In short, if you make a bad choice, the owners might not care about helping with harassment, which looks a lot like the big corporate sites, though for different reasons.  If you make a good choice, moderation works better, plus that "fire-hose" that I mentioned points you to a bunch of interesting people on your server, with interests that overlap yours.  You can find servers where people---in addition to their normal communications---bond over geographic location, anime, association with the LGBT community, comic books, support of sex workers, political activism, or plenty of other topics.  (You could also run your own server, but let's not delude ourselves into thinking that would improve your life at this stage.)

Again, though, if you don't feel like doing that kind of research, pick pretty much any server, because you have no obligation to interact with anybody else there, and they won't know that they have someone ignoring them.

I don't know why people have so much trouble with this concept.  Mastodon looks a lot like...oh, just about everything else that you deal with in your everyday life:  You need to pick a provider, and those providers differ in minor and also sometimes unexpected ways.  Have you ever shopped for food, insurance, or a phone plan?  Then you already understand this.  In these situations, you *can* carefully research your options to optimize for some specific part of the experience, but accidentally buying the worst possible phone plan still lets you communicate with people on other plans.  If you buy the worst corn at the market (absent an aberrant bacterial infection), it works in the same recipe as the best corn.

### Or Maybe Not Mastodon at All

This gets a *bit* more difficult to explain, but not much, so let's present another possible decision, where you have the option of ignoring it.  Maybe you like the sorts of people you find on Mastodon, but don't like something about Mastodon itself.  You might not like its user interface, or don't particularly enjoy microblogging.

If so, then you can play, too.  The same technology that lets people talk to each other on different Mastodon servers can also allow people to replace Mastodon with a website that presents its information in different ways.  Again, think of this decision as low-stakes, but you can choose an alternative if you prefer.

 * If you like microblogging, but don't like something about Mastodon in particular, then you might investigate [Misskey](https://misskey-hub.net/en) or [Pleroma](https://pleroma.social/), while trying to feel more modern, in different ways.
 * If you expect to post a lot of pictures or really like Instagram's interface, then you might take a look at [Pixelfed](https://pixelfed.org/).
 * Does video-sharing sound more like your style?  [PeerTube](https://joinpeertube.org/en) takes its design cues from YouTube, and so might work well for you.
 * Maybe you would prefer something that looks like Reddit, in which case, you might appreciate [Lemmy](https://join-lemmy.org/) more.
 * If you prefer long-form posts, then you might want to take a look at [WriteFreely](https://writefreely.org/) or [Plume](https://joinplu.me/).
 * If you love sharing music and miss Grooveshark, then you might want to look at [Funkwhale](https://funkwhale.audio/).
 * Do you need to coordinate events?  You might want [Mobilizon](https://mobilizon.fr/), instead.
 * The list goes on.  [BookWyrm](https://joinbookwyrm.com/) focuses on reading and reviewing books.  [Inventaire](https://inventaire.io/welcome) handles book inventory.  [Castopod](https://castopod.org/) focuses on podcast publishing.  Many others exist, but a lot of them seem unfinished or unfriendly.

Like with the server, you *do not need* to put much thought into this, if you don't want.  Just pick Mastodon, if this feels overwhelming, because Mastodon has the longest history and the largest community of developers, and so has more stability.  And like I said, the pieces that allow different Mastodon servers communicate also allow a Mastodon user follow someone on PeerTube or any of the others, but each site presents the information differently.  In many cases, Mastodon users see the photographs, videos, blog posts, music recommendations, or events as toots, and the other systems see replies as comments for the original post.  Everybody sees the network in the way that they prefer...which I assume makes a good metaphor for something or other.

## Finding and Getting Found

Now that you have (presumably) signed up on something connected to Mastodon, you should probably do some basic work to rebuild something like your Twitter network.  I mean, maybe not.  Maybe you use social media to speak your mind and don't follow anybody or care who follows you.  If so, then you can skip this step.

### Leave Some Breadcrumbs

For everybody else, make sure that people can find your account on Mastodon or wherever.  The current standard---we'll talk about why, in a bit---has you put your new address into your Twitter bio or a pinned tweet.  For example, my bio never had much to it, so I had plenty of room to add this.

 > @jcolag@mastodon.social on Mastodon.

Technically, I have more than that, since I also use [Diaspora](https://www.joindiaspora.org/), but nobody cares about that as far as I know.  Regardless, if you can't fit your Mastodon handle into your bio, because it already has a lot of other details, then you can tweet something along the lines of "I invite everyone to follow me on Mastodon @jcolag@mastodon.social," and pin that tweet, instead.

### Follow Some Breadcrumbs

Once you have that settled, sign in at [Debirdify](https://debirdify.pruvisto.org/), [Fedifinder](https://fedifinder.glitch.me/), or some similar Twitter-to-Mastodon search tool, if you have friends who recommend something else.  These tools will look at your Twitter network, and check their bios and pinned tweets for the information that I had you supply earlier in this section.

You can now follow, block, or otherwise deal with those people as you please.  You can also check back every few days.  As more people move over to Mastodon and similar services, the more people will follow them over.  Currently, I see about one percent of the people I follow move per day.

By the way, if you haven't chosen a server, yet, you could do worse than using this tool to figure out where the accounts that you care about went, and go where the largest number of them went.  If you see a green check mark next to the server name, it'll accept your account without review.

### Twitter Lists?

If you have a list that you created, Debirdify has you covered, one of the buttons listed under *Advanced*.

However, I see two caveats.

First, I haven't found a way of moving a Twitter list that somebody *else* created, yet, other than checking each person on the list individually and building a new list in Mastodon.  I'll update this post, if I have a breakthrough, and I encourage anybody with a solution to post it in the comments.

Second, Mastodon lists...don't really thrill me.  You can only add a person to a list if you follow them.  I do partly use Twitter's lists to give me easier access to people who I follow whose posts I don't want to miss.  However, I also use several lists as a kind of parallel timeline, people who I don't want to follow in general, but occasionally have something interesting to say.

Most people who use Twitter's lists seem to use them for harassment, though, so I'll accept the substandard feature to disrupt their garbage.

## Self-Verify, If Appropriate

If you have some official status somewhere, or publish your own work---like I do, here on the blog---then you might want to make it clear that the "official you" runs your Mastodon account.  However, you'll need some technical knowledge, here.

To make this work, head over to Mastodon's *Preferences*, then click on *Profile*, and *Appearance*.  Near the bottom of that page, you'll see some inputs with the useless-sounding label of "Profile metadata."  Despite the lousy name, you use them to identify yourself across the Internet.  For example, the top line of my "metadata" says that I have a "Personal Website" (type that into the left-hand column) of `https://john.colagioia.net` (in the right-hand column).

Then, to the right of the "metadata" list, you should see a section labeled "Verification."  That includes some HTML code that you can copy to the webpage(s) that you listed as metadata.

Once you have that set up, the webpage will show up on your profile, highlighted in green with a checkmark.  For example, my profile points you to [my personal website, here](/), so that you can confirm that the same person (me) runs my account and my website.

This doesn't take the place of (hypothetical, non-broken) Twitter verification, because a curious user needs to check your profile and verify that the website says what you claim that it says, but it does give you some control and legitimacy.

You can also use the metadata for smaller details like your [preference in pronouns]({% post_url 2020-09-20-pronoun %}), should people talk about you.

### The Techie Solution

**Update, 2022 December 07**:  This section didn't appear in prior versions of the post.

You can also identify yourself with an encryption key, if you don't have a website.  It takes a bit more work, especially if you haven't used public-key encryption before, but I followed Seth Kenlon's [*6 Steps to Get Verified on Mastodon with Encrypted Keys*](https://opensource.com/article/22/12/verified-mastodon-pgp-keyoxide), and it worked fine on the first try.

If this seems confusing to you, public-key encryption works by having people generate two "keys," one that you keep private and one that you publish.  They work opposite to each other, so that encryption and decryption use the same process, with different keys.

It dramatically oversimplifies the work involved, but imagine if your encryption scheme multiplied a numerical message by the key.  If you have keys of 2 and 0.5, then those would allow one person to encrypt the message and the other to decrypt it, or the reverse.  You can then publish one key, and keep the other secret.  Anybody who knows you can then read messages that you publish ("sign") with your key.  People can also encrypt messages that only you can read.

Here, you publish a key so that people can identify your Mastodon account.

In any case, note that the final steps look a lot like the process for a website:  After you upload your information, you point at it in your profile's "metadata."

### In the Future...

Better verification would *probably* come from running your own server with a well-known domain name.  Specifically, while a validated link in a profile doesn't do much for realizing that the person's claimed identity matches their actual identity, you can probably trust that someone whose handle comes from a major media outlet or government agency actually has a connection with that organization, and people would see *that* information in each post.

In other words, a hypothetical `@potus@pixelfed.whitehouse.gov` account has significantly more credibility than a `@potus@random.website.invalid` account with a verified link to <https://whitehouse.gov>.  That doesn't apply to everyone, but if you do happen to run an organization, want your people to have a presence on Mastodon, and want them to act in some official capacity, give some thought to it.  It makes more sense than opening a public Mastodon server for your fans.

## Download Your Archives

You should probably start making regular backups of your social media data.  I know, nobody enjoys making backups.  But they occasionally come in handy, and backing up your data generally allows you to *restore* your data if something happens, which makes people happier than the backups themselves.

First, go to [Twitter's account settings](https://twitter.com/settings/account) and select *Download an archive of your data*.  Type your password, follow the directions, and Twitter will (start the process to) provide you with an archive of your tweets, replies, accounts that you follow, and much more.  Why?  If there comes a point where you don't want to return to Twitter---or can't, because the current management runs them out of business, which sounds increasingly possible---then you'll still have access to everything that you've written and done.

Then, head to your Mastodon (or other service) server's export.  You'll probably find that following the links that say *Preferences*, *Import and export*, and finally *Data export*.  Twitter seems like precarious system *now*, but remember, individuals (sometimes small groups) run Mastodon servers.  Nobody enjoys thinking about this, but if an individual runs your server, then a single accident could cut the funding to the server in an instant, to say nothing of the single person feeling overwhelmed and deciding to give up their hobby.  If that happens, then you can import your data to another server, and point your friends/followers over to your new account.

I would hazard a guess that nobody *will* do these things regularly, but you should.  It won't take you long, and it can save you trouble in the future, if sites start having trouble.

## Fitting in

Now that we have the administrative chores out of the way, we can talk about posting.  In my opinion, you should understand three things.

### Set Content Warnings

Unlike Twitter, Mastodon gives you the ability to set a content warning on your posts.  **Use them**.  The time that you want to waste telling me why you have an important exception, go use it to write content warnings for your posts.

Remember where I started this post.  Twitter wants us out there upsetting each other, so that (indirectly) we'll click on ads.  If your angry rant about a politician, accompanied by terrifying photographs, triggers somebody's post-traumatic stress, that works to Twitter's benefit, and they would prefer that you do that as often as possible.

By contrast, while you might find some exceptions, Mastodon servers don't have advertising.  That short-circuits the entire "outrage feedback loop," and so the software has no interest in encouraging you to shock people, and nobody has any value in traumatizing the community.

Therefore, show some minimal courtesy to the people reading your posts, and wrap anything sensitive with a content warning, so that people know what you might get them into.  Think broadly, here.  You'll probably instinctively flag something for gory violence or pornography, sure, but you might also consider marking political commentary with the name of the relevant country or state, so that people nowhere near you---or feeling stressed---can skip it.  You might also warn about likely disinterest:  Many people wrap warnings around discussions/pictures of their kids and pets, too, because they acknowledge that some people don't want to see it, for various reasons.  Similarly, because of the different communities, now that I cross-post to Mastodon from Twitter, I apply a warning that I wrote the post for Twitter's environment.

Many people on Mastodon will only give you a few chances, here.  If you keep posting triggering, insensitive, or just plain boring content without adding a clear warning for people, they'll solve that problem for themselves, by ignoring you.  When in doubt, let the reader know what you've offered them, instead of assuming that they'll appreciate it.

As you grow accustomed to the community, you'll get a better sense of what you can reasonably post without a warning, but you'll annoy fewer people if you err on the side of caution, as you get started.

#### Yes, I Know...

I hear you grumbling in the back, there.  Yes, for the sake of social progress, a person might need to spread the word about an injustice as quickly as possible, and that drastically can outweigh the comfort of readers.

And sure, I can get behind that, to some extent.  However, ask yourself a question before committing to this:  Do your examples *really* deal with a critical international social justice issue?  I would guess that they don't, so slap a content warning on that, and respect your audience's needs.

In fact, you know that hashtag that you created or borrowed to properly express your rage, grief, or context?  The text of would make an excellent title for a content warning.  Use the same phrasing to help people find the conversation or ignore the conversation.

### Manage Your Expectations

Hand in hand with the content warnings, don't expect to use Mastodon to become a star.  People often joke about five likes (favorites?) and a reply as "going viral," partly because of the smaller community, but primarily because Mastodon doesn't have a big corporation throwing algorithms and artificial intelligence to spread posts to make the largest (negative) emotional impact.

Going back to where we started again, Twitter wants people afraid and angry.  It facilitates this by analyzing the tweets that people "engage with," and promoting those interactions, when people wander off reading.  Mastodon doesn't have that, so you probably won't see any exponential growth or massive jumps in your audience.

In other words, don't expect to "go viral."  In fact, don't expect a dashboard of metrics showing you which posts got the "most engagement," or even consistent feedback of who liked your post.  Expect to have conversations and organize, and try to detoxify from that constant enforced stress.

### Don't Expect Many VIPs

Related, the lack of ways to push a message in front of people makes a platform like Mastodon undesirable to a large class of potential users.  If they can't "promote" their posts in search rankings or game the system, brands and politicians will almost never bother.  Without brands and politicians, journalists have little reason to show up.  Without journalists, you probably won't see many celebrities looking for their attention.

Because of that, you probably won't get into many arguments with mule-headed Congressional Representatives, find opportunities to make fun of sloppy journalists, or get the approval of a famous performer.  They might *eventually* find reasons to get Mastodon accounts---for example, if millions of people start using it regularly---but for now, they probably won't.

## Enjoy

At the risk of oversimplifying the foregoing, Mastodon resembles Twitter in a lot of ways, but it doesn't replace everything that people use Twitter for.  Nothing would, and nothing can replace everything that people use Mastodon for.  The two systems work on entirely different paradigms, so we shouldn't expect them to act the same.

However, within those limits, you can get a message out, have a lot of fun, and get to know some great people, extremely *similar* to Twitter.  And it'll almost certainly feel more comfortable than flocking back to Facebook or finding the *next* company that wants to mine your interests for ad revenue.

#### <i class="fab fa-mastodon"></i>

* * *

**Credits**:  The header image is [Knight Mastodon](https://commons.wikimedia.org/wiki/File:Knight_Mastodon.jpg) by Charles R. Knight, long in the public domain.
