---
layout: post
title: Why Care about Free Culture?
date: 2023-06-25 07:38:12-0400
categories:
tags: [rant, freeculture, media]
summary: Explaining why I often focus where I do
thumbnail: /blog/assets/117878252_3c00463c07_o.png
teaser: I try to give an overview of why I make a big deal on this blog about Free Culture, and why it could matter to you, too.
proofed: true
---

As happens on some of these Sunday posts, the idea for this struck me quickly, and I tried to pull something together for today.  As a result, you might consider this a first draft of the actual post, since I guarantee that---if I ever took the time to carefully re-read it, which probably won't happen---I'd want to restructure most of it and probably rewrite half.  In other words, I apologize if this comes out messier than a typical post.

![A logo representing Free Culture, featuring a sketch of three definitely generic modular brick toys stacked as a corner](/blog/assets/117878252_3c00463c07_o.png "The original organization appears to have abandoned their use of the logo, so I might as well use it here...")

Every so often, a reader will contact me privately to---never in so many words---question the utility of the [Free Culture Book Club](/blog/tag/bookclub).  And while somewhat uncomfortable, I consider that enough of a legitimate question that I feel like using as a springboard to get to some deeper questions.

## Some Review

When I [launched the book club]({% post_url 2020-05-02-freeculture %}) a little more than three years ago, I talked about a few outcomes that I wanted from this project.

 * Find not only Free Culture "works," but Free Culture *worlds*.
 * Discover Free Culture works that can plausibly outlive the interest of their creators, ideally works that could withstand some attention by new creators.
 * Provoke discussion about those works, here or elsewhere.

Of those, I have found many works---so far, over ninety---in various genres and media.  Of those, I don't know about you, but at least *I* would say that many of them, both completed or seemingly abandoned and a couple in progress, could withstand some additional contributors.

I haven't seen much of a visible community, but that may come as much from too-high expectations as it would from a lack of interest.  Consider the following, after all.

 * Unless you happen to live inside a circle with a roughly fifteen-mile radius, you won't find many people who know or care that I exist.  Those who do know me primarily do from [teaching]({% post_url 2020-01-19-teaching %}), work, or frequenting certain restaurants, *not* my writing or anything like cultural preservation.
 * I only ever do the barest minimum to publicize my blog posts, announcing them on social media, and *not* on any of the big sites.
 * Free Culture might seem like a complicated concept to a lot of people, in a world that rarely needs to think about copyright.
 * Interestingly, I could argue that a community *has* begun to form, though not on my blog.  People do interact with the announcements of my blog posts on social media, and seem to get to know each other, there.  I've even had some pleasant discussions with several creators.

That makes a long way around saying that, while I haven't attracted a visible community of Free Culture fanatics...that result makes a lot of sense, and I don't think that I'd have more "success" at it without some sort of improbable celebrity endorsement.  I also don't consider it a "failure," as such, in that I have my blog posts archived in multiple places, meaning that people can find them (if not each other) long after I've stopped paying server bills.

I'd like to go deeper than that, though, and get to some over-arching motivations involved in this.

## Why "Free Culture"

I have to admit that the term *Free Culture* doesn't sit well with me, either, but I also can't find a term that sounds both concise and descriptive, and this at least connects to the Free Software movement.  And we need to call it *something*, when consumers can use a work for any purpose, which I don't think that we have, otherwise.

As such, despite the fact that it only even barely qualifies as a niche term, which the average person doesn't have any familiarity with, it basically works.

## Why Culture at All?

As most readers probably already know, I work as a software engineer, and I write and maintain a variety of small Free Software projects.  And so you might reasonably ask why I spend so much time on stories that---at least on average---probably won't ever win any awards.

In the end, I consider this the flip-side of using a niche term like "Free Software."  I *could* take a [random ticket from a Free Software project that I use](https://github.com/jekyll/jekyll/issues/9351) that sounds like it would interest me, do the testing, poke around the code to figure out where things have gone wrong, and write a decent-length blog post explaining all that, yes.  But I can't think of many people who would find that interesting enough to read.  You'd need to find people with interest and experience in programming---preferably Ruby, in this case---and a specific interest in Jekyll.  And while those people exist, who reads a blog post to go off to fix the problem described?

By contrast, we all understand a novel or a movie, so anybody can follow what I want to talk about, if they choose.  Similarly, you might not personally have the experience to fix some arcane Jekyll problem, but I would bet that you have more than enough experience to correct a typo in or remove an irrelevant sentence from a book.  You *probably* even have enough experience to find a boring character and make them seem more interesting.

In this way, Free Culture has the ability to get people accustomed to the ideas in Free Software, without dealing with programming.  And we can have some fun doing it.

### Overcoming Bad Marketing

Incidentally, while on the subject of Free Software and the difficulty of getting the point of it across to people, I should take a moment to point out how thoroughly the so-called "leaders" of the movement have fouled this up.

For example, I've [complained about the FSF]({% post_url 2021-05-09-fsf %}) in the past, for example, but it bears repeating that they constantly and almost deliberately alienate everyone around them, then wonder why more people don't join their club.  When they try to reach out to new audiences, they try to pack in so many keywords without context that it sounds like utter gibberish.  And they refuse to let go of this 1970s idea that only programmers would ever care about software, and so constantly talk about the freedom to change code, rather than community.

Alternatively, if I use the more corporate-friendly term "Open Source," you end up in a world where most of the search results point to libraries.  Because again, the people involved in the movement don't seem to understand that non-programmers use computers, these days.

Therefore, it seems almost pointless to start educating people about these movements from the perspective of software, because when they go off to do further research, they'll hit an unnecessary brick wall.

## What Do We Mean by Free?

I already talked about this a bit, above, but when I talk about Free Culture---or Free Software, for that matter---I mean works that anybody can use for any purpose, subject to laws.  Specifically, we couldn't get away with rewriting someone's essay to mean the opposite *and* blame the original author for advocating something horrible, nor could we use a photograph of a person to imply endorsement of a product, because most jurisdictions have laws preventing that sort of nonsense.  However, we *can* read it, share it with friends, publish it, make sweeping changes to it, translate it, or use it as the basis of a big-budget film.

While I occasionally grump about the quality of this work or that, we should think of every Free Culture work as at least a kind of gift.  Modern copyright law assigns monopoly rights over all published creative work, and some people choose to use that monopoly to spread around most of those rights to anybody who wants to "infringe."  You can think of this in terms of fan fiction, if you like, because we all have permission to write a [*Floraverse*]({% post_url 2020-05-23-seeds %}) story, I think of it more in terms of joint custody.

And like I mentioned earlier, I decided on a "book club" format---rather than "reviews" or "spotlights"---specifically because those distributed rights mean that we don't really have a right to call something *bad*.  We can only volunteer to improve it, because the creator has offered it to us on those terms.  The same generally holds true for Free Software, though no software project can guarantee that all its users who have complaints will have experience in developing software; but when someone claims that a hypothetical short story has bad writing, they absolutely have the skills and technological support to fix what they see as a problem.

## Why Care?

Now we get to the central issue.  What difference does all this make?

We live in a highly concentrated media landscape.  For film in the United States and Canada, for example, [five parent companies](https://en.wikipedia.org/wiki/Major_film_studios) control over ninety percent of the market, through somewhere in the neighborhood of a hundred fifty subsidiaries; six parent companies control most of our local television.  Three parent companies control the vast majority of the American music market; similarly for video games.  Radio jumps up to five parent companies.  And these companies, predictably, share investors and board members in various ways, so we actually have even tighter concentration than it appears.  In most other countries, the company names change, but the statistics don't.

In addition, we all have reasons to dislike how those companies run their media empires, though reasons may differ from individual to individual.  We may object to streaming services deleting content, as if those shows and films never existed.  Every change in management leading to a mass cancellation of projects might get to us.  Some of us may have a problem with the unending sameness, including---but certainly not limited to---a steady stream of reboots and expansions of existing franchises.  We might not like the lack of social consciousness in productions.  Or your objection might look completely different.  The actual objection doesn't matter, because when you only have three to eight companies controlling the market, *they don't care* about your objection.  They only care about getting as many people as possible to pay as much as they can afford.

### Indies?

We can turn to independent productions, but there, we run the risk of a big conglomerate buying out the independent studio/publisher, and using it as "camouflage" to make big-budget productions seem less cynical.  For example, it seems like a foregone conclusion that Disney will eventually buy [Amblin Partners](https://en.wikipedia.org/wiki/Amblin_Partners), to me.  It may not happen until after Steven Spielberg's death, but the intellectual property seems like it fits precisely into Disney's current primary business model of cornering the nostalgia market for parents.

We also run the risk that the independent corporation will *become* a major player in the future.  For an example there, we can think of [MGM](https://en.wikipedia.org/wiki/Metro-Goldwyn-Mayer) as independent, since it has less than one and a half percent of the film market.  However, Amazon owns MGM, and Amazon can pour money into marketing films and acquiring other small studios, until it can challenge Disney for the top spot.

In other words, we can't really trust A24 to solve our problems.

### Non-Commercial Licenses

Can we look at non-commercial works?  In theory, and I like several, myself, but they set themselves up for failure.  While a [Cory Doctorow](https://en.wikipedia.org/wiki/Cory_Doctorow) (to pick someone who probably won't take offense at my using him as an example, if he reads this) might publish interesting stories, and his choice of license might---but probably won't, if someone has strong enough motivation---prevent companies from profiting from his work without explicit permission, his non-commercial licensing means that his work can only have fans, not collaborators.  As the only person with permission to sell works based on his concepts, his decisions or those of his heirs carry far more weight than anybody else's.

The same goes for any non-commercial-licensed work, and this feeds directly into the foregoing.  As I've said about social media companies, a dollar value exists, whether through direct purchase or more indirect or even underhanded means, that can put ownership of Doctorow's works into the hands of a Disney.  That new owner can, in turn, then treat it like every other franchise, producing more sameness, while also carefully monitoring fan-works under the pretext that something looks too "commercial" for their interpretation of the license.

### Back to Free Culture

By contrast, Free Culture works give us a way to overcome all these obstacles.

#### Copyleft versus Anti-Commercial

As I've written about in an early post on this blog, [share-alike clauses stand a better chance of deterring corporate involvement]({% post_url 2019-12-28-licenses %}) than non-commercial clauses.  A company like Disney might well try to argue that it hasn't violated your non-commercial license with its summer blockbuster film, because they promise to donate [every dollar of profit](https://en.wikipedia.org/wiki/Hollywood_accounting)---which will amount to some nominal sum that constitutes a rounding error in the corporate budget---to charity.  Or they could take a more brazen approach of claiming that a contract can't forbid them from making a profit.

Alternatively, a studio could also buy the copyright of a non-commercial publication *to* exploit it commercially, while using the non-commercial license as a bludgeon to police the people creating derived works.

However, no studio---unless market conditions change dramatically, and probably for the worse for writers---will ever release a film where any of us can edit or modify it and sell the result as our own product.

Honestly, even providing attribution to someone outside the existing creative unions would probably already stretch a big studio's limits.

**Update**:  I didn't discover this until shortly after the post went out, but photographer Jeremy Keith has a story that shows how [attribution derails big companies <i class="fas fa-copyright"></i>](https://adactio.com/journal/1530/).

#### Resistant

Unlike an independent studio, you can't really name a dollar value that would put a Free Culture work under effective corporate ownership.  Even if Activision dropped a massive pile of money on the creators of [**Snowbound Blood**]({% post_url 2023-03-25-snowbound-blood-1 %}) for the rights to the code and story, the creators have already given up exclusive rights.

As such, while Activision or another game studio could plausibly create new works based on the game, and refuse to let anybody else adapt it, so could you or I, because the public license only requires that we give Deconreconstruction credit.  No matter how much a prospective buyer wants to spend, no price will rescind the permission given to us to modify, adapt, or continue Free Culture works.

Even if Deconreconstruction grows to become a video game behemoth, and put in effort to wall off their work, we still have their Free Culture work to do with as we please.

#### Variety, Driven by You

If the sameness of modern franchises bothers you, Free Culture has almost unlimited diversity.  We have seen [comedies about sperm donation]({% post_url 2020-09-26-joneses1 %}), [post-apocalyptic solarpunk]({% post_url 2021-12-18-wormwood-1 %}), [medieval zombie outbreaks]({% post_url 2021-06-19-solitudes1 %}), [demonic Boston]({% post_url 2020-05-09-orangu %}), [useless right-wing superheroes]({% post_url 2021-04-10-fellowship %}), [Lunar colonists]({% post_url 2022-04-30-lunatics %}), [cryptid hunters]({% post_url 2023-04-22-sasquatch-1 %}), a [griping software engineer who needs his ex-wife to bolster his ego]({% post_url 2020-12-26-biodigital %}), and much more.

Do some of these works bear a strong resemblance to larger franchises?  Absolutely.  We have that, too.

More importantly, though, the license allows *you* to become the next creator with established characters and settings.  Do you believe that the media landscape suffers from an extreme lack of French superheroes as sock puppets racing cars while listening to Korean death metal?  Knock my socks off with the best [Superflu]({% post_url 2022-12-03-superflu %}) story that anybody will ever see.  Each of us can take these worlds in wildly different directions, if we don't want to build our own.

And while I focus my discussion on fiction, the same applies to non-fiction, as well.  Does [**The American Yawp**](https://www.americanyawp.com/) not include recent revelations?  Do you feel that [WikiNews](https://www.wikinews.org/) publishes politically biased reports?  Or do you think that [**BBS:  The Documentary**](http://www.bbsdocumentary.com/) wastes far too much of its five-hour run-time with the demo scene?  You can fix those, too, and either try to contribute your efforts back or publish them yourself.

Speaking of which, if I could create a motto for the Free Culture movement, I'd have to go with this.

## Become the Crackpot That You Wish to See in the World...

This should give some idea of why I get so excited about Free Culture, even if I don't have dozens of people debating works every Saturday morning.

Specifically, these works put the power to create and collaborate in our hands, freeing us from media oligopolies, beyond advice that we should create our own works.  And if my writing about them doesn't find a vocal audience immediately, the works have no intention of going anywhere...

And yes, I *do* realize the contradiction inherent in saying that we don't need to worry about these works vanishing the day after posting about [a comic that has vanished]({% post_url 2023-06-24-move-forward %}) and may never return.

Oh, and since I really should get better at soliciting comments, since I *know* that I have readers interested in Free Culture things---I can see several of you in the analytics, from around the world, diligently going from post to post---I'll ask here, and *specifically* invite interested readers to discuss it in the comments:

Does anyone have their eye on any specific Free Culture work that you have an itch to use for another project?

To kick that discussion off myself:  Despite my complaints about the works, **Biodigital** and [**Life Blood**]({% post_url 2022-12-31-life-blood-1 %})---along with some [*SCP*]({% post_url 2020-10-31-pumpkin %}) concepts---actually have a lot in common with an idea for a series of stories that I've kicked around, so I may well try to do something with our lovelorn protagonists and the diabolical cults out to get them.

* * *

**Credits**:  I adapted the header image from [FC.o logo](https://www.flickr.com/photos/mllerustad/117878252/in/set-72057594090576065/) by [Karen Rustad Tölva](https://www.flickr.com/photos/mllerustad/), made available under the terms of the [Creative Commons Attribution 2.0 Generic](https://creativecommons.org/licenses/by/2.0/) license.  They created the original version for [FreeCulture.org](http://freeculture.org/), but you can see as well as I can that the site no longer exists in any meaningful way, so I decided to appropriate it...
