---
layout: post
title: My Linux Story
date: 2024-02-18 07:19:12-0500
categories:
tags: [rant, linux]
summary: I ramble about history rhyming and why I primarily run Linux
thumbnail: /blog/assets/3671554921_2a5a24d6ac_o.png
teaser: Microsoft's recent changes to Windows remind me of a previous fiasco that drove me out of Microsoft's ecosystem.
spell: coreboot ReactOS OpenSolaris Illumos sfx eyeroll Duststorm
proofed: true
---

The recent widespread annoyance---at least in my social media circles---at Microsoft integrating its [Copilot](https://en.wikipedia.org/wiki/Microsoft_Copilot) chatbot into what seems like everything reminds me a lot of what feels like a lifetime ago, when I started to make the full-time switch to using Linux as my primary and almost exclusive operating system.

![Paper cranes made from paper with the old Ubuntu logo on it](/blog/assets/3671554921_2a5a24d6ac_o.png "How has nobody used this for an autonomous vehicle post?")

Will this provide any lessons to anybody concerned about Microsoft's new business model?  I honestly have no idea. {% emoji person shrugging %} But the story might amuse someone, and it at least feels mildly timely.

## Some Background

As I've probably mentioned before, for most of my early life---longer than I should probably admit, in fact---I used a [Commodore 64](https://en.wikipedia.org/wiki/Commodore_64) as my only computer.  It had everything that I needed for a long time, plus the best-by-far graphics and music, especially for the price.  And I only really stopped using mine for school work, when Commodore's forty-character line lengths made my papers look sloppy, and it became difficult to find a new compatible printer.  I *could* print eighty-character lines like everyone else, but that required using the [Commodore 1520 plotter](https://en.wikipedia.org/wiki/Commodore_64_peripherals#Plotter), which used scrolls with the approximate width of toilet paper that looked fairly absurd, *and* if the mechanism slipped, it could end up overwriting earlier lines of text.

By the time that I could no longer get away with using old Commodore products productively---and with the [Amiga](https://en.wikipedia.org/wiki/Amiga) far out of my price range and an entirely different monster---my family got an IBM PC-compatible package, with a more traditional (for the time) dot-matrix printer.  The computer had [CGA](https://en.wikipedia.org/wiki/Color_Graphics_Adapter) graphics with a whopping four colors over 320 by 200 pixels (or sixteen colors, if you dropped the resolution to a hundred pixels by a hundred), and audio limited to a beeping speaker, but it printed in a standard way, which I needed.  It ran [MS-DOS](https://en.wikipedia.org/wiki/MS-DOS), I want to say version 3.3 or thereabouts; that gave me my first direct exposure to Microsoft.

While I can't say that I *liked* working with MS-DOS, I built a grudging respect for its modularity.  If you didn't see any use for some component, you could probably delete it or replace it.  And it did provide valuable services---particularly for input and output---that a programmer could use from assembly language.

And then came Windows, specifically [Microsoft Windows, version 3.1](https://en.wikipedia.org/wiki/Windows_3.1).  It didn't really function as an operating system as such, but more a graphical shell over MS-DOS.  And I took an instant dislike to it.  I couldn't tell you how genuinely I felt that dislike, considering that I researched to find obscure features, and it sounds a lot like me at that age to dismiss something because it felt "too popular" or "too easy."  More importantly, though, it didn't last long, and I soon considered myself "a Windows user."

At that point, I also had my first exposures to UNIX, in the form of then-Sun's [Solaris](https://en.wikipedia.org/wiki/Oracle_Solaris) operating system, which I genuinely liked.  Sure, it required what we'd probably call a mainframe to run it, but it ran smoothly and looked great doing it.

Shortly after that, I had my first exposure to Linux, and...it didn't measure up.  That makes perfect sense, because I probably mean only two or three years after Torvalds released the first version of the kernel, but I saw an ugly graphical environment that seemed prone to crashing with no warning, and it might trash its own configuration files on the way out.  The kernel, as far as I could tell, constantly needed adjustments and re-compiling, which took *forever*.  And software only existed if you tracked it down and compiled it for your specific system.

You probably didn't need to know most of that, but I figured that I'd get out of the way that I didn't start out predisposed to using Linux.  In contrast to almost every other system that enabled productivity, using Linux seemed to me to primarily revolve around maintaining Linux.

## Fast Forward to 2010

Years and Windows versions passed, and Microsoft began previewing [Windows 8](https://en.wikipedia.org/wiki/Windows_8).  Many people complained about the mobile-oriented look, but by that point, I had tired of that sort of whining after seeing---and sometimes participating in---it with Windows 3.1, Windows 95, Windows XP, and Windows Vista, before it.  Instead, I objected to Microsoft requiring that Windows 8-certified hardware support [Secure Boot](https://en.wikipedia.org/wiki/UEFI#Secure_Boot_criticism), making the company a gatekeeper of which operating systems can run on what could become the overwhelming majority of commodity hardware.

As you know in hindsight, Microsoft has mostly acted fairly towards independent operating system developers to date.  We haven't heard many stories of Microsoft not providing a signing key to get through the Secure Boot process.  This may have had something to do with a combination of the public outcry and [coreboot](https://en.wikipedia.org/wiki/Coreboot) becoming a viable alternative to UEFI.

However, not knowing how this would shake out at the time, the shift pushed me to find an alternative, in case Microsoft went the full route of [iOS](https://en.wikipedia.org/wiki/IOS), with full control over everything from the hardware to the selection of available software.  And that, not to mention the price, ruled out Apple products, which Microsoft seemed to want to emulate.

I had recently worked in an office where they ran Ubuntu, and didn't hate it.  I didn't need to do any administration work, so I didn't know what that would take, but that question seemed like a central part of the experiment.

### Many Possibilities

Consider the alternatives at the time, by the way.  [ReactOS](https://reactos.org/) seems interesting, but risky in a few ways.  [FreeBSD](https://www.freebsd.org/) looks identical to Linux, for my purposes, but with less support.  [OpenSolaris](https://en.wikipedia.org/wiki/OpenSolaris) seemed interesting but had already vanished, and [Illumos](https://illumos.org/) hadn't quite established itself, nor did I know how Oracle would manage that relationship as it took over Sun's branding everywhere.  I could never tell if [Haiku](https://www.haiku-os.org/), [Plan 9 from Bell Labs](https://p9f.org/), or [Inferno](https://www.vitanuova.com/inferno/) would seriously work, nor would I have any idea where one got software for them, back then, other than manually compiling everything.

I could churn thorough a bunch more alternatives, but you get the general idea:  The options either looked so much like a modern Linux that I probably wouldn't know the difference, *or* didn't have enough labor behind it to feel like a serious contender.

## How-To

If you want to try to follow my path to using Linux regularly, or want an approximate guide that you can quickly adapt to your needs, I present the process that I went through, as well as I can remember it.

### Inventory

First, I took stock of the software that I used regularly *on my home computer*.  I make that distinction, because you can stumble right into the weeds by worrying about replicating your work computer, too---assuming that you work for somebody else who supplies you with a computer---or software that you once installed but never bothered to use.  For each item on the list of software that you use, you'll need to see which category it falls into.

 * Software already available on Linux.
 * Software that has a ready substitute on Linux.
 * Software with an online version, where your desktop application probably only acts like a web browser.
 * Software with no Linux-accessible counterpart.

In short, you want to know how much work you have ahead of you.

For my case, I already mostly used Free Software at home, by that point, so knew that I wouldn't have much of an adjustment on that front.  A work computer for me might need Visual Studio, but I don't generally do much C# work on my own time, certainly not enough that I need an IDE for it.

### Setting up

Once you have your software list figured out, pick a Linux distribution or other operating system.  Don't overthink this, because it doesn't matter much and you can always change your mind.  If you have experience using something, choose that one.

Third, get yourself a cheap laptop.  Back when I did this, you could find [netbooks](https://en.wikipedia.org/wiki/Netbook) widely available, so I went that route.  But a used laptop should also work.  You'll install your Linux distribution on this machine.

Why a separate computer, instead of sharing space on the computer you already use?  I suspect that you'll want to spend some time switching between systems to check on issues like rendering, and you *probably* won't do that, if you need to reboot your computer to get into the other operating system.  You also want to make the choice of operating system as frictionless as possible, so that you can make it freely.

With a separate computer, you also don't risk anything except whatever you pay for a cheap computer, these days.  It won't happen, but if your installation of Linux "goes rogue" and starts overwriting files with the trashiest high-fantasy fiction, then that disaster won't affect the computer that you currently use.  Put another way, the separation can give you the peace of mind to experiment, because you can't do much damage.

And I say to get a laptop for this, because that removes placement from the reasons that might affect which computer that you use.

Fourth, as mentioned, install your Linux distribution on the laptop.  In most cases, this means writing the installer to a USB stick, booting to the USB stick, and clicking the big "Install" button.  The process probably won't get more technical than finding the instructions to do this...unless you want more complexity.

Fifth---and I consider this maybe the most important step---choose to live with the defaults.  I don't care if you desperately want aquamarine as the default color, the close button in the upper-left, round window corners, or whatever.  Do *not* waste your time messing around with configuration.

I say this for a couple of reasons.  Primarily, if you spend all your time on Linux configuring Linux, then you'll never have time to find out if it'll do the job for your routine work.  But also, configuration can rapidly get out of hand, where you suddenly forget why you've copied options from three different websites and hope that they don't break anything.  Whatever your distribution looks like, accept it, at least for now.

### Go...

And here, the experiment starts.  You now have two computers with different operating systems.  Which one do you reach for, when you need to work on something?  Other than setting up file-sharing to access your work from the other system, how often do you find yourself working at one computer over the other?

In my case, after about a week, my Windows computer acted entirely like a file-server for the Linux box.  I kept the machine running, because I needed my files, but barely touched the user interface.  Your situation might not swing that far over, but the experience quickly showed me that I didn't need to bother with Windows anymore.

## Pitfalls

I should note the handful of cases where I've had problems.

Note that you might have problems that I never see, because I may not care about those areas.  For example, I couldn't tell you what mainstream gaming looks like, since my game collection includes a couple of old Humble Bundles---back when they focused on independent studios---an occasional for-charity bundle from Itch, and Free Software.  And even then, I don't spend much time playing, because I have too much of an itch to make things.

### Teleconferencing

Getting on a video call with friends has become a logic puzzle where we each try to list all the networks that we've gotten to work recently, then determine the maximal overlaps.

Zoom works consistently.  Microsoft Teams for web sometimes works, though it has limitations; an unofficial desktop build exists, but nobody wants to even *guess* what it'll do.  Google's works about half the time.  I haven't tried Slack or Discord, but as pure web applications, I would expect them to work.

All the Free Software teleconferencing platforms work, *but* getting a group of friends to show up there has its own roadblocks, and it becomes even more difficult for a professional relationship.

### E-Books

I once made the mistake---before getting a library card and discovering their apps---of purchasing an e-book that I wanted to read.  All major publishers currently only produce digital copies of their material with onerous [DRM](https://en.wikipedia.org/wiki/Digital_rights_management) that only allows you to stream the content in segments, so that one doesn't have the temptation to {% sfx gasp! %} share text with friends.

Of those major publishers, none of them bothers to target Linux as a platform where people might want to read.  Booksellers also don't bother to mention this, so you end up buying a compressed XML file with URLs that would tell software where to request encrypted paragraphs, if you had that software.

When I confronted the seller, to their credit, they refunded my money immediately and apologized.  But if you want to read on a normal computer, expect to only get books from authors who'll sell to you directly.

### Reading DVDs

A while back---coinciding with early issues of the [**Entropy Arbitrage** newsletter](https://buymeacoffee/jcolag), as it turns out---I undertook the process of "ripping" my stacks of DVDs to a media server, so that I could actually watch them.  No experience, after all, matches up to having a streaming service in your living room that primarily includes things that you want to see, and that where nothing appears based on shaky contracts between companies that might expire at any time without warning.

In any case, I had a painful few weeks trying to find Linux software that could deal with [CSS](https://en.wikipedia.org/wiki/Content_Scramble_System) (no, the *other* one) and its successors.  Even paid [codecs](https://en.wikipedia.org/wiki/Codec) failed, or software would refuse to acknowledge them.

Presumably, *some* legitimate solution exists, out there.  For the sake of expediency, though, I ended up running an old Windows machine---Windows has all the required codecs built in---to do the boring work of pulling poorly encrypted video files from the discs.

## Old Problems

I haven't had them, yet, but it seems fairly routine for certain classes of hardware to not have Linux support, particularly Wi-Fi modules.  You might want to blame the Linux community for not supporting part of your new device, but this generally happens because the vendor won't supply any information on the device to developers.  If the vendor encrypted any part of the system, even trivially, then working out how to connect to it could violate various anti-hacking laws around the world.  {% emoji eyeroll %}

As I said, though, I haven't personally had this problem, and haven't heard a "real" Linux user mention it in a long time.  I've only heard it mentioned by people trying to scare people away from Linux.  That doesn't make it untrue or obsolete, though, because many manufacturers do still find Free Software threatening.

## After-Effects

I don't know how accurately this holds, or if it would even apply to anybody but me, but at least in my retelling of the various stories, I credit my deep interest in Free Culture to my shift over to regularly using Ubuntu.

Sure, maybe the two changes happened to coincide.  However, I can't help but think that, over the course of a few weeks, my choice of Linux distribution centered three things in my vision, every day.

 * A showcase of software licensed under the GPL, a reciprocal license that at least *seems* to work far better than the alternatives.
 * A modest showcase of Free Culture works, because Ubuntu previously shipped with media such as [Josh Woodward's songs]({% post_url 2022-03-26-woodward %}); I don't believe that Ubuntu does this anymore.
 * The African-origin [ubuntu](https://en.wikipedia.org/wiki/Ubuntu_philosophy) philosophy that defines us as humans by our relationships and community.

I previously had an interest in material that had fallen out of copyright protection into the public domain, with the intent of using it for various business purposes, a story for another day, maybe.  You could, therefore, maybe argue that I didn't sit so far from becoming something of a copyleft advocate.  However, the ideas presented by Ubuntu *may* have also pushed me to think more in terms of contributing to the commons, rather than trying to stockpile material and extract from it.

Those ideas, specifically, led me to think about Free Software's value as its collaboration, not its results.  They led me to dismiss the idea of building on the public domain purely in order to secure a new copyright on something.  And they certainly led me to push further away from big-corporate silos for my consumer habits.

Again, I don't know that this *actually* tells a story of causation, or if that cause would apply more widely than me, but I did want to mention it.

## Give It a Try

If you've gotten tired of huge transnational companies trying to control your computer for you, at least look into non-corporate alternatives.  What you find might surprise you...or it might not.  But at least, then, you'll know.

And those of you who make the switch, I do wonder if you find any odd shifts in priorities like I believe that I did...

* * *

**Credits**:  The header image is [Ubuntu Cranes](https://www.flickr.com/photos/duststorm01/3671554921) by [Duststorm](https://www.flickr.com/photos/duststorm01/), made available under the terms of the [Creative Commons Attribution 2.0 Generic](https://creativecommons.org/licenses/by/2.0/) license.
