---
layout: post
title: Wanted — Ethical Media Consumption
date: 2020-08-02 10:38:12-0400
categories:
tags: [media, license, ethics, rant]
summary: Theorizing about what "ethical viewing" might mean.
thumbnail: /blog/assets/aditya_ram21.png
offset: -38%
---

This post may turn out sounding disjointed, as I try to work some ideas out on the fly.  Because, while it's obvious that many people *think* about this topic, there doesn't appear to be any organized thought around it.  So, I mean this as a jumping-off point for discussions, rather than a contained idea or narrative.

Specifically, I want to give some thought to media consumption habits and where we might consider setting boundaries to our entertainment, what sorts of events or revelations might trigger changes in those boundaries, and what setting those boundaries accomplishes.  Again, I don't have any answers beyond what I do in my own life, but I do have a lot of questions that feel worth the trouble of asking.

![Some media](/blog/assets/aditya_ram21.png "Some media")

Because the reasons we might consider interacting with certain media products and their creators can tend to range from simple disagreements to histories of brutal criminal acts, consider this a fairly weak content warning.  To talk about the reasons we might want to avoid supporting some creators, I'm going to need to mention certain creators---I'll try to keep it to the usual crowd---and mention what they've done to warrant a lack of support.  If those references are likely to trigger anxiety issues, this would be a good opportunity to take a break from reading to prepare yourself for that.

## Disclaimer

I'm not interested in judging some universal value of art, whether to tell any reader that they should or should not be enjoying some piece of media, whether universally or conditionally.  If you feel guilty about something as you read, here, those feelings are your responsibility and *exactly* what this post is about.

Also, while I interrogate the possible bad results of supporting media from certain people, it's a safe bet that I do so.  I would like to stop the harmful business practices at Amazon or Disney, but I have subscriptions for both.  I own books and music written by some terrible people.  To the extent that any of this is a genuine problem, I'm part of the problem and looking for a way to not be so, rather than standing in judgment of anybody else.

## Some Background

One of the aspects I enjoy most about writing the [Free Culture Book Club](/blog/tag/bookclub/) posts is digging through media that would probably never be particularly successful in the mainstream.  [**Jathia's Wager**]({% post_url 2020-05-16-jathia %}) is a prime example, here, something that would probably never exist outside a forgotten box in the creator's closet, if it wasn't for the Free Culture ethos.  Related is the joy of seeing the lines between creator and fan blur into a common community, such as with [**Manuel, the Marvelous Mechanical Man**]({% post_url 2020-07-11-manuel %}) reviewing and accepting pull requests on GitHub.

That community can be a double-edged sword, however.  Particularly when there are vulnerable people in the audience, such as minors, it's not hard to find incidents where people especially close to the creators use their position to exploit and abuse them, the victims afraid to come forward against someone with a strong reputation.  The community spirit is obviously less joyful, when it harbors abusers and fails to support victims.

In addition, I wrote recently about the [inherent weirdness of "Cancel Culture"]({% post_url 2020-07-12-tolerance %}).  Especially given the potential issues with communities---and this is in no way limited to Free Culture products---it necessarily raises the question of when we (as in "each of us," not "all of us") should go about ignoring works of art and other media as they turn out to be products of some type of abuse.

## The Problem

When we dig deeper into the subject, the core question becomes something along the lines of realizing that supporting art---by definition---means supporting artists *and* whatever those artists chose to support.  Whether that support is financial or just attention, the support has consequences.  And I would argue that we need to understand those consequences, acknowledge them, and decide what consequences we're willing to live with and which we're not.

We can probably all recite the famous versions of this in our sleep.  [Roman Polanski](https://en.wikipedia.org/wiki/Roman_Polanski#Sexual_abuse_case) has spent over forty years in self-imposed exile from the United States, rather than face justice for forcibly having sex with a minor.  Directory [Bryan Singer](https://en.wikipedia.org/wiki/Bryan_Singer#Sexual_abuse_allegations) has a shopping list of sexually related abuse accusations against him, in addition to treating his cast and crew more generally inappropriately.  [J.K. Rowling](https://en.wikipedia.org/wiki/Politics_of_J._K._Rowling#Transgender_people) frequently repeats transphobic propaganda.

Again, we all know the names and stories, but similar things are obviously also true of some fraction of people who produce lesser-known art, too.  So, this discussion isn't about whether we should support media backed by money or not.  That would be useless.

Plus, mass media art can be fun.

However, something that *is* (mostly) unique to large companies is the chance that a company has divisions that works on projects that cause harm some of us might want to avoid.  As one example, American mass media has consolidated into less than ten companies; the exact number depends on how you count them.  One of those large companies, Comcast, was founded---and until 2013, partly owned---by General Electric, one of the top military contractors in the world.  YouTube and Google News are owned by Alphabet, which tracks and monitors users.  Disney is known for treating employees poorly, erasing the contributions of non-White people, stereotyping and minimizing non-White, non-straight characters, lobbying for stronger Intellectual Property protections, forming what's effectively a horizontal and vertical monopoly, and (like most movie studios) accepts money from the military in exchange for script oversight while also excluding material that might be attacked if released overseas.

Oh, and we shouldn't forget about money laundering.  There are enough money laundering scandals surrounding certain Hollywood movies that we can probably guess that it happens more often than we see.

So, the problem is having the toolkit to be able to decide whether we want our money and/or attention to be given to a particular venture.

## Analogous Situations

Media seems to be one of the last frontiers, when it comes to ethics.

If I want to be an ethical *eater*, I can pick any combination of sources to help make my decision.

 * Many restricted diets---particularly vegetarianism and veganism---have implicit (and sometimes explicit) ethical codes attached to them, such as a refusal to accept animal cruelty, with varying definitions of cruelty.
 * Heavily-processed foods complicate and obscure the supply chain, which complicates the decisions.
 * Local foods in season have a lower environmental impact than alternatives.
 * Small-scale food production, such a local farm, might allow you to watch the process to help you understand where your food comes from.
 * Free or restricted trade policies affects which crops and which farmers get more support.
 * Certifications provide information ranging from treatment of livestock to the chemicals used in growing to the approaches taken to hardiness.
 * Fair trade certifications gives a sense of labor practices along the supply chain.

No, it's not ideal.  Yes, some criteria on the list might conflict at points.  However, it's not only a start, some aspects of [ethical eating](https://en.wikipedia.org/wiki/Ethical_eating)---such as ordering seafood---can be distilled down to a wallet-sized card that includes ratings for things like mercury levels and sustainability.

Similarly, when it comes to large online services, the Electronic Frontier Foundation publishes their [Who Has Your Back?](https://www.eff.org/wp/who-has-your-back-2019) annual reports.  It's also a field that attracts a lot of research, so it's not difficult to find a way to quantify allegations of bias or abuse.

Even in more general consumerism, there are standards that can be used to judge corporate governance, ecological impact, labor practices, forest sustainability, charitable giving, recyclability, repairability, compatibility with Free Software licenses, health and safety, and so forth.

Heck, media itself warns us all the time that we might see part of a naked body, and websites like [Does the Dog Die? <i class="far fa-copyright"></i>](https://www.doesthedogdie.com/) even collecting information about specific diverse media that might trigger somebody's anxiety.

Somehow, though, deciding whether to see a movie for ethical reasons is a research project.

## My State of the Art

Since there isn't already a system in place for me to just steal, I'm stuck feeling my way around the edges hoping to find something that works.  So far, here's what I have settled on.

First, **anything I already own on physical media is exempt**.  I can't change the past and it would be a waste of time to try to purge my library of material I don't want to support...after I've already supported it.  Destroying the material isn't a good solution and giving it away merely passes the problem on to somebody else, so if I ever get around to watching my **Superman Returns** DVD (it came in a collection before the accusations against Singer were widely known), it doesn't register as support for him anywhere, and no more money is being spent on him.  The worst that happens is that I might acknowledge his skill as a director.

Similarly, **if the work is in the public domain or released under a Free Culture license, separate art from artist where possible**.  The reason for this---I hope---is fairly obvious:  Free Culture works can be adapted into works that directly oppose the actions of a bad creator.  The works of H.P. Lovecraft are a good example, here.  Lovecraft himself was a bigot and it shows through in many of his stories.  However, he's long dead and it's easy to attribute his beliefs to his characters while acknowledging that they're wrong in the story.

As a follow-on to that separation, **acknowledge and try to balance any known harm done**.  As I mentioned at the top, I pay for a Disney+ subscription to watch certain things.  In doing so, I feel like I give up my right to be ignorant of Disney's business practices and need to support independent artists with at least the same money.  Likewise, my use of Amazon Prime Video means that I limit my use of Amazon as an e-commerce site unless I literally can't find the product anywhere else.  Eventually, that will feel like a waste of money and the media subscription will be the first on the chopping block.

**One accusation is only an accusation**.  While I take accusations from victims seriously and believe them enough to want every incident investigated, a single accusation *could* be an exaggeration, misunderstanding, or unfortunate incident.  From the standpoint of a consumer, a small part of my purchase going to someone who made a mistake isn't terrible, and offenders should have the opportunity to make amends.

However, **where there's smoke, there's fire**.  Where an accusation sounds particularly credible or is just the first of many accusations, the probability that it was a wacky misunderstanding drops quickly.  Likewise, when the fake-apology or half-denial sounds worse than the initial offense, it's time to move on.

**Judge a work by its community response**.  When there is an incident in a community around a work and a victim comes forward, the reaction of the creators and fans tells you a lot about what you support.  One example that took me by surprise were the accusations against the creator of the **Kingdom of Loathing** browser game.  While the team has tended to be supportive of women's voices, they chose to not engage when it hit home and refused to provide a framework to ensure that vulnerable members of the community would be protected in the future.  Then, they would give interviews pointing fingers at each other to deflect blame from themselves.  By contrast, the [*Floraverse*]({% post_url 2020-05-23-seeds %}) community chat apparently had an incident where a popular community member close to the creator had been abusing some other members of the community.  In that case, it has led to an outpouring of support for the victims and frank talk about how to protect vulnerable people in the future.  Those responses make it easy to see who deserves support.

**Refuse to identify with media**.  Liking a franchise enough to participate in the community is fine.  Arguing with someone over which franchise is better is unacceptable, mainly because both franchises are run by mega-corporations that don't actually care who in the audience feels alienated.  Don't defend them when someone claims they're not "art" and don't wonder why they take up so few progressive causes; they're billionaires, that's why.  They're not on your team.

It's a start, but I know it's not enough and feels shoddier now that I've put it into words.  So, if anybody wants to run with this, please do so.  I'll be happy to throw whatever support I can muster behind a good attempt at formalizing this sort of thing.

Where do you draw these lines, if at all?

* * *

**Credits**:  The header image is [Adityaram Media having the studios for movie shootings](https://morguefile.com/p/956254) by [Adityaram](https://morguefile.com/creative/Adityaram), made available under the terms of the [Morgue File license](https://morguefile.com/license) that I *think* is basically compatible with the blog's license.
